﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Text;
using Kreta.DataAccessManual.Interfaces;
using Kreta.DataAccessManual.Util;
using Kreta.Enums;
using Kreta.Framework;
using SDA.DataProvider;

namespace Kreta.DataAccessManual
{
    internal class EugyintezesDal : DataAccessBase, IEugyintezesDal
    {
        public EugyintezesDal(DalHandler handler) : base(handler) { }

        public DataSet GetAlkalmazottak(int tanevKretaAzonosito)
        {
            using (var command = new SDACommand())
            {
                command.Connection = UserContext.Instance.SDAConnection;
                command.Transaction = UserContext.Instance.SDATransaction;
                command.CommandType = CommandType.StoredProcedure;
                command.CommandText = "uspGetAlkalmazottakEugyintezesByKretaAzonosito";

                command.Parameters.Add("pTanevKretaAzonosito", tanevKretaAzonosito);

                var dataSet = new DataSet();
                using (var sdaDataAdapter = new SDADataAdapter())
                {
                    sdaDataAdapter.SelectCommand = command;
                    sdaDataAdapter.Fill(dataSet);
                }

                SetDNAME(dataSet.Tables[0], "Titulus");
                return dataSet;
            }
        }

        public DataSet GetAlkalmazott(int azonosito, int? tanevKretaAzonosito)
        {

            if (!tanevKretaAzonosito.HasValue)
            {
                tanevKretaAzonosito = GetTanevId(azonosito);
            }

            using (var command = new SDACommand())
            {
                command.Connection = UserContext.Instance.SDAConnection;
                command.Transaction = UserContext.Instance.SDATransaction;
                command.CommandType = CommandType.StoredProcedure;
                command.CommandText = "uspGetAlkalmazottakEugyintezesByAzonositoAndKretaAzonosito";

                command.Parameters.Add("pAzonosito", azonosito);
                command.Parameters.Add("pTanevId", tanevKretaAzonosito);

                var dataSet = new DataSet();
                using (var sdaDataAdapter = new SDADataAdapter())
                {
                    sdaDataAdapter.SelectCommand = command;
                    sdaDataAdapter.Fill(dataSet);
                }

                SetDNAME(dataSet.Tables[0], "Titulus");
                return dataSet;
            }
        }

        public DataSet GetGondviseloGyerekAdatok(int gondviseloAzonosito)
        {
            using (var command = new SDACommand())
            {
                command.Connection = UserContext.Instance.SDAConnection;
                command.Transaction = UserContext.Instance.SDATransaction;
                command.CommandType = CommandType.StoredProcedure;
                command.CommandText = "uspGetGondviseloGyerekAdatok";

                command.Parameters.Add("pGondviseloAzonosito", gondviseloAzonosito);

                var dataSet = new DataSet();
                using (var sdaDataAdapter = new SDADataAdapter())
                {
                    sdaDataAdapter.SelectCommand = command;
                    sdaDataAdapter.Fill(dataSet);
                }

                return dataSet;
            }
        }

        public int GetKozossegiSzolgalatOsszesIgazoltOrakSzama(string tanuloOktatasiAzonosito)
        {
            using (var command = new SDACommand())
            {
                command.Connection = UserContext.Instance.SDAConnection;
                command.Transaction = UserContext.Instance.SDATransaction;
                command.CommandType = CommandType.StoredProcedure;
                command.CommandText = "uspGetKozossegiSzolgalatOsszesIgazoltOrakSzama";

                command.Parameters.Add("pTanuloOktatasiAzonosito", tanuloOktatasiAzonosito);

                var result = command.ExecuteScalar();

                if (result != null && int.TryParse(result.ToString(), out int id))
                {
                    return id;
                }

                return 0;
            }
        }

        public DataSet GetKozossegiSzolgalatTevekenyseg(int azonosito, int tanevId)
        {
            using (var command = new SDACommand())
            {
                command.Connection = UserContext.Instance.SDAConnection;
                command.Transaction = UserContext.Instance.SDATransaction;
                command.CommandType = CommandType.StoredProcedure;
                command.CommandText = "uspGetKozossegiSzolgalatTevekenyseg";

                command.Parameters.Add("pTanevId", tanevId);
                command.Parameters.Add("pAzonosito", azonosito);
                command.Parameters.Add("pTipusId", (int)GeneratedAdatszotarTipusEnum.KozossegiSzolgalatTipus);

                var dataSet = new DataSet();
                using (var sdaDataAdapter = new SDADataAdapter())
                {
                    sdaDataAdapter.SelectCommand = command;
                    sdaDataAdapter.Fill(dataSet);
                }

                return dataSet;
            }
        }

        public DataSet GetKozossegiSzolgalatTevekenysegek(int tanevId)
        {
            using (var command = new SDACommand())
            {
                command.Connection = UserContext.Instance.SDAConnection;
                command.Transaction = UserContext.Instance.SDATransaction;
                command.CommandType = CommandType.StoredProcedure;
                command.CommandText = "uspGetKozossegiSzolgalatTevekenysegek";

                command.Parameters.Add("pTanevId", tanevId);
                command.Parameters.Add("pTipusId", (int)GeneratedAdatszotarTipusEnum.KozossegiSzolgalatTipus);

                var dataSet = new DataSet();
                using (var sdaDataAdapter = new SDADataAdapter())
                {
                    sdaDataAdapter.SelectCommand = command;
                    sdaDataAdapter.Fill(dataSet);
                }

                return dataSet;
            }
        }

        public DataSet GetOsztaly(int azonosito)
        {
            int tanevKretaAzonosito = GetOsztalycsoportTanevId(azonosito);

            using (var command = new SDACommand())
            {
                command.Connection = UserContext.Instance.SDAConnection;
                command.Transaction = UserContext.Instance.SDATransaction;
                command.CommandType = CommandType.StoredProcedure;
                command.CommandText = "uspGetOsztalyEugyintezesByAzonosito";

                command.Parameters.Add("pTanevId", tanevKretaAzonosito);
                command.Parameters.Add("pOsztalyCsoportId", azonosito);

                var dataSet = new DataSet();
                using (var sdaDataAdapter = new SDADataAdapter())
                {
                    sdaDataAdapter.SelectCommand = command;
                    sdaDataAdapter.Fill(dataSet);
                }

                return dataSet;
            }
        }

        public DataSet GetOsztalyok(int tanevKretaAzonosito)
        {
            using (var command = new SDACommand())
            {
                command.Connection = UserContext.Instance.SDAConnection;
                command.Transaction = UserContext.Instance.SDATransaction;
                command.CommandType = CommandType.StoredProcedure;
                command.CommandText = "uspGetOsztalyokEugyintezesByKretaAzonosito";

                command.Parameters.Add("pTanevId", tanevKretaAzonosito);

                var dataSet = new DataSet();
                using (var sdaDataAdapter = new SDADataAdapter())
                {
                    sdaDataAdapter.SelectCommand = command;
                    sdaDataAdapter.Fill(dataSet);
                }

                return dataSet;
            }
        }

        public DataSet GetOsztalyTanulok(int osztalyAzonosito)
        {
            using (var command = new SDACommand())
            {
                command.Connection = UserContext.Instance.SDAConnection;
                command.Transaction = UserContext.Instance.SDATransaction;
                command.CommandType = CommandType.StoredProcedure;
                command.CommandText = "uspGetOsztalyTanulokByOsztalyId";

                command.Parameters.Add("pOsztalyAzonosito", osztalyAzonosito);

                var dataSet = new DataSet();
                using (var sdaDataAdapter = new SDADataAdapter())
                {
                    sdaDataAdapter.SelectCommand = command;
                    sdaDataAdapter.Fill(dataSet);
                }

                return dataSet;
            }
        }

        public DateTime? GetTanevKezdete(int intezmenyId)
        {
            using (var command = new SDACommand())
            {
                command.Connection = UserContext.Instance.SDAConnection;
                command.Transaction = UserContext.Instance.SDATransaction;
                command.CommandType = CommandType.StoredProcedure;
                command.CommandText = "uspGetAktivTanevKezdete";

                command.Parameters.Add("pIntezmenyId", SDADBType.Int).Value = intezmenyId;

                var result = command.ExecuteScalar();

                if (result != null && DateTime.TryParse(result.ToString(), out DateTime dateTimeResult))
                {
                    return dateTimeResult;
                }

                return null;
            }
        }

        public DataSet GetTanoraiCsoport(int azonosito)
        {
            int tanevKretaAzonosito = GetOsztalycsoportTanevId(azonosito);

            using (var command = new SDACommand())
            {
                command.Connection = UserContext.Instance.SDAConnection;
                command.Transaction = UserContext.Instance.SDATransaction;
                command.CommandType = CommandType.StoredProcedure;
                command.CommandText = "uspGetTanoraiCsoport";

                command.Parameters.Add("pTanevId", tanevKretaAzonosito);
                command.Parameters.Add("pOsztalyCsoportId", azonosito);

                var dataSet = new DataSet();
                using (var sdaDataAdapter = new SDADataAdapter())
                {
                    sdaDataAdapter.SelectCommand = command;
                    sdaDataAdapter.Fill(dataSet);
                }

                return dataSet;
            }
        }

        public DataSet GetTanoraiCsoportok(int tanevId)
        {
            using (var command = new SDACommand())
            {
                command.Connection = UserContext.Instance.SDAConnection;
                command.Transaction = UserContext.Instance.SDATransaction;
                command.CommandType = CommandType.StoredProcedure;
                command.CommandText = "uspGetTanoraiCsoportok";

                command.Parameters.Add("pTanevId", SDADBType.Int).Value = tanevId;

                var dataSet = new DataSet();
                using (var sdaDataAdapter = new SDADataAdapter())
                {
                    sdaDataAdapter.SelectCommand = command;
                    sdaDataAdapter.Fill(dataSet);
                }

                return dataSet;
            }
        }

        public DataSet GetTanoraiCsoportTanulok(int tanuloiCsoportAzonosito)
        {
            using (var command = new SDACommand())
            {
                command.Connection = UserContext.Instance.SDAConnection;
                command.Transaction = UserContext.Instance.SDATransaction;
                command.CommandType = CommandType.StoredProcedure;
                command.CommandText = "uspGetTanoraiCsoportTanulok";

                command.Parameters.Add("pTanuloiCsoportAzonosito", tanuloiCsoportAzonosito);

                var dataSet = new DataSet();
                using (var sdaDataAdapter = new SDADataAdapter())
                {
                    sdaDataAdapter.SelectCommand = command;
                    sdaDataAdapter.Fill(dataSet);
                }

                return dataSet;
            }
        }

        public DataSet GetTantargy(int tantargyAzonosito)
        {
            int tanevKretaAzonosito = GetTantargyTanevId(tantargyAzonosito);
            using (var command = new SDACommand())
            {
                command.Connection = UserContext.Instance.SDAConnection;
                command.Transaction = UserContext.Instance.SDATransaction;
                command.CommandType = CommandType.StoredProcedure;
                command.CommandText = "uspGetTantargyEugyintezesByAzonosito";

                command.Parameters.Add("pTanevId", tanevKretaAzonosito);
                command.Parameters.Add("pTantargyAzonosito", tantargyAzonosito);

                var dataSet = new DataSet();
                using (var sdaDataAdapter = new SDADataAdapter())
                {
                    sdaDataAdapter.SelectCommand = command;
                    sdaDataAdapter.Fill(dataSet);
                }

                return dataSet;
            }
        }

        public DataSet GetTanuloAdatok(string tanuloOktatasiAzonosito, int? tanevKretaAzonosito, string intezmenyAzonosito)
        {
            if (!tanevKretaAzonosito.HasValue)
            {
                int intezmenyId = GetIntezmenyId(intezmenyAzonosito);
                tanevKretaAzonosito = GetTanevId(tanuloOktatasiAzonosito, intezmenyId);
            }

            using (var command = new SDACommand())
            {
                command.Connection = UserContext.Instance.SDAConnection;
                command.Transaction = UserContext.Instance.SDATransaction;
                command.CommandType = CommandType.StoredProcedure;
                command.CommandText = "uspGetTanuloAdatokEugyintezes";

                command.Parameters.Add("pTanevId", tanevKretaAzonosito);
                command.Parameters.Add("pTanuloOktatasiAzonosito", tanuloOktatasiAzonosito);

                var dataSet = new DataSet();
                using (var sdaDataAdapter = new SDADataAdapter())
                {
                    sdaDataAdapter.SelectCommand = command;
                    sdaDataAdapter.Fill(dataSet);
                }

                return dataSet;
            }

        }

        public DataSet GetTanuloAdatokNextYear(string tanuloOktatasiAzonosito, int tanevKretaAzonosito)
        {
            using (var command = new SDACommand())
            {
                command.Connection = UserContext.Instance.SDAConnection;
                command.Transaction = UserContext.Instance.SDATransaction;
                command.CommandType = CommandType.StoredProcedure;
                command.CommandText = "uspGetTanuloAdatokNextYearEugyintezes";

                command.Parameters.Add("pTanevId", tanevKretaAzonosito);
                command.Parameters.Add("pTanuloOktatasiAzonosito", tanuloOktatasiAzonosito);

                var dataSet = new DataSet();
                using (var sdaDataAdapter = new SDADataAdapter())
                {
                    sdaDataAdapter.SelectCommand = command;
                    sdaDataAdapter.Fill(dataSet);
                }

                return dataSet;
            }
        }

        public DataSet GetTanuloTantargyak(string tanuloOktatasiAzonosito, int tanevId)
        {

            using (var command = new SDACommand())
            {
                command.Connection = UserContext.Instance.SDAConnection;
                command.Transaction = UserContext.Instance.SDATransaction;
                command.CommandType = CommandType.StoredProcedure;
                command.CommandText = "uspGetTanuloTantargyakByOktatasiAzonosito";

                command.Parameters.Add("pTanuloOktatasiAzonosito", SDADBType.String).Value = tanuloOktatasiAzonosito;
                command.Parameters.Add("pTanevId", SDADBType.Int).Value = tanevId;

                var dataSet = new DataSet();
                using (var sdaDataAdapter = new SDADataAdapter())
                {
                    sdaDataAdapter.SelectCommand = command;
                    sdaDataAdapter.Fill(dataSet);
                }

                return dataSet;
            }
        }

        public void SendIedm(string tanuloOktatasiAzonosito, DateTime tavolletKezdete, DateTime tavolletVege)
        {
            throw new NotImplementedException();
        }

        public DataSet GetKozteruletJellege(int azonosito, int tanevId)
        {
            using (var command = new SDACommand())
            {
                command.Connection = UserContext.Instance.SDAConnection;
                command.Transaction = UserContext.Instance.SDATransaction;
                command.CommandType = CommandType.StoredProcedure;
                command.CommandText = "uspGetKozteruletJellege";

                command.Parameters.Add("pTipusId", (int)GeneratedAdatszotarTipusEnum.KozteruletJelleg);
                command.Parameters.Add("pId", azonosito);
                command.Parameters.Add("pTanevId", tanevId);

                var dataSet = new DataSet();
                using (var sdaDataAdapter = new SDADataAdapter())
                {
                    sdaDataAdapter.SelectCommand = command;
                    sdaDataAdapter.Fill(dataSet);
                }

                return dataSet;
            }
        }

        public DataSet GetKozteruletJellegek(int tanevId)
        {
            using (var command = new SDACommand())
            {
                command.Connection = UserContext.Instance.SDAConnection;
                command.Transaction = UserContext.Instance.SDATransaction;
                command.CommandType = CommandType.StoredProcedure;
                command.CommandText = "uspGetKozteruletJellegekEugyintezes";

                command.Parameters.Add("pTanevId", tanevId);
                command.Parameters.Add("pKozteruletJellegeNa", (int)KozteruletJellegEnum.na);
                command.Parameters.Add("pTipusId", (int)GeneratedAdatszotarTipusEnum.KozteruletJelleg);

                var dataSet = new DataSet();
                using (var sdaDataAdapter = new SDADataAdapter())
                {
                    sdaDataAdapter.SelectCommand = command;
                    sdaDataAdapter.Fill(dataSet);
                }

                return dataSet;
            }

        }

        public DataSet GetGondviseloEmailCim(int kretaAzonosito)
        {
            using (var command = new SDACommand())
            {
                command.Connection = UserContext.Instance.SDAConnection;
                command.Transaction = UserContext.Instance.SDATransaction;
                command.CommandType = CommandType.StoredProcedure;
                command.CommandText = "uspGetGondviseloEmailCimEugyintezes";

                command.Parameters.Add("pId", kretaAzonosito);

                var dataSet = new DataSet();
                using (var sdaDataAdapter = new SDADataAdapter())
                {
                    sdaDataAdapter.SelectCommand = command;
                    sdaDataAdapter.Fill(dataSet);
                }

                return dataSet;
            }
        }

        public DataSet GetFelhasznaloEmailCim(int kretaAzonosito)
        {

            using (var command = new SDACommand())
            {
                command.Connection = UserContext.Instance.SDAConnection;
                command.Transaction = UserContext.Instance.SDATransaction;
                command.CommandType = CommandType.StoredProcedure;
                command.CommandText = "uspGetFelhasznaloEmailCimEugyintezes";

                command.Parameters.Add("pId", kretaAzonosito);

                var dataSet = new DataSet();
                using (var sdaDataAdapter = new SDADataAdapter())
                {
                    sdaDataAdapter.SelectCommand = command;
                    sdaDataAdapter.Fill(dataSet);
                }

                return dataSet;
            }
        }

        public DataSet GetTanuloTanoraiCsoportok(string tanuloOktatasiAzonosito)
        {

            using (var command = new SDACommand())
            {
                command.Connection = UserContext.Instance.SDAConnection;
                command.Transaction = UserContext.Instance.SDATransaction;
                command.CommandType = CommandType.StoredProcedure;
                command.CommandText = "uspGetTanuloTanoraiCsoportokEugyintezes";

                command.Parameters.Add("pTanuloOktatasiAzonosito", tanuloOktatasiAzonosito);

                var dataSet = new DataSet();
                using (var sdaDataAdapter = new SDADataAdapter())
                {
                    sdaDataAdapter.SelectCommand = command;
                    sdaDataAdapter.Fill(dataSet);
                }

                return dataSet;
            }
        }

        public DataSet GetOsztalyTanoraiCsoportok(int osztalyKretaAzonosito)
        {

            using (var command = new SDACommand())
            {
                command.Connection = UserContext.Instance.SDAConnection;
                command.Transaction = UserContext.Instance.SDATransaction;
                command.CommandType = CommandType.StoredProcedure;
                command.CommandText = "uspGetOsztalyTanoraiCsoportokEugyintezes";

                command.Parameters.Add("pOsztalyKretaAzonosito", osztalyKretaAzonosito);

                var dataSet = new DataSet();
                using (var sdaDataAdapter = new SDADataAdapter())
                {
                    sdaDataAdapter.SelectCommand = command;
                    sdaDataAdapter.Fill(dataSet);
                }

                return dataSet;
            }
        }

        public DataSet GetTanulokByTanoraiCsoport(int kretaAzonosito)
        {
            using (var command = new SDACommand())
            {
                command.Connection = UserContext.Instance.SDAConnection;
                command.Transaction = UserContext.Instance.SDATransaction;
                command.CommandType = CommandType.StoredProcedure;
                command.CommandText = "uspGetTanulokByTanoraiCsoportEugyintezes";

                command.Parameters.Add("pOsztalyCsoportId", kretaAzonosito);

                var dataSet = new DataSet();
                using (var sdaDataAdapter = new SDADataAdapter())
                {
                    sdaDataAdapter.SelectCommand = command;
                    sdaDataAdapter.Fill(dataSet);
                }

                return dataSet;
            }
        }

        public DataSet GetTanulokByOsztaly(int kretaAzonosito, int tanevKretaAzonosito, bool isKovetkezoTanev)
        {
            StringBuilder commandTextBuilder = new StringBuilder($@"
                SELECT
                  Felhasznalo.ID AS KretaAzonosito
                 ,Felhasznalo.C_VEZETEKNEV AS VezetekNev
                 ,Felhasznalo.C_UTONEV AS KeresztNev
                 ,Felhasznalo.C_OKTATASIAZONOSITO AS OktatasiAzonosito
                 ,ISNULL(Felhasznalo.C_ELOTAG, '') AS Elotag
                 ,OsztalyCsoport.C_NEV AS Osztaly
                 ,Felhasznalo.C_SZULETESIDATUM AS SzuletesiIdo
                 ,Felhasznalo.C_EGYEDIAZONOSITO AS EgyediAzonosito
                 ,Felhasznalo.C_IDPEGYEDIAZONOSITO AS IdpEgyediAzonosito
                FROM T_OSZTALYCSOPORT_OSSZES OsztalyCsoport
                INNER JOIN T_TANULOCSOPORT_OSSZES TanuloCsoport ON TanuloCsoport.C_OSZTALYCSOPORTID = OsztalyCsoport.ID");

            if (!isKovetkezoTanev)
            {
                commandTextBuilder.AppendLine(@"
                    AND TanuloCsoport.C_BELEPESDATUM <= (SELECT IIF(GETDATE() < C_ELSOTANITASINAP, C_ELSOTANITASINAP, GETDATE()) FROM T_TANEV WHERE C_AKTIV = 'T' AND TOROLT = 'F')
                    AND (TanuloCsoport.C_KILEPESDATUM IS NULL OR TanuloCsoport.C_KILEPESDATUM > GETDATE())");
            }

            commandTextBuilder.AppendLine($@"
                INNER JOIN T_FELHASZNALO_OSSZES Felhasznalo ON  Felhasznalo.ID = TanuloCsoport.C_TANULOID
                WHERE OsztalyCsoport.ID = @{nameof(kretaAzonosito)}
                 AND OsztalyCsoport.C_TANEVID = @{nameof(tanevKretaAzonosito)}
                 AND Felhasznalo.TOROLT = 'F'
                 AND TanuloCsoport.TOROLT = 'F'
                 AND OsztalyCsoport.TOROLT = 'F'");

            var ds = GetData(commandTextBuilder.ToString(), new List<CommandParameter> {
                new CommandParameter(nameof(kretaAzonosito), kretaAzonosito),
                new CommandParameter(nameof(tanevKretaAzonosito), tanevKretaAzonosito)
            });

            return ds;
        }

        public DataSet GetTanevek(int intezmenyId)
        {
            using (var command = new SDACommand())
            {
                command.Connection = UserContext.Instance.SDAConnection;
                command.Transaction = UserContext.Instance.SDATransaction;
                command.CommandType = CommandType.StoredProcedure;
                command.CommandText = "uspGetTanevekEugyintezes";

                command.Parameters.Add("pIntezmenyId", SDADBType.Int).Value = intezmenyId;

                var dataSet = new DataSet();
                using (var sdaDataAdapter = new SDADataAdapter())
                {
                    sdaDataAdapter.SelectCommand = command;
                    sdaDataAdapter.Fill(dataSet);
                }

                return dataSet;
            }
        }

        public DataSet GetOsszesTanevek(int intezmenyId)
        {
            using (var command = new SDACommand())
            {
                command.Connection = UserContext.Instance.SDAConnection;
                command.Transaction = UserContext.Instance.SDATransaction;
                command.CommandType = CommandType.StoredProcedure;
                command.CommandText = "uspGetOsszesTanevekEugyintezes";

                command.Parameters.Add("pIntezmenyId", SDADBType.Int).Value = intezmenyId;

                var dataSet = new DataSet();
                using (var sdaDataAdapter = new SDADataAdapter())
                {
                    sdaDataAdapter.SelectCommand = command;
                    sdaDataAdapter.Fill(dataSet);
                }

                return dataSet;
            }
        }

        public DataSet GetSZMKOsztalyok(int gondviseloKretaAzonosito)
        {

            using (var command = new SDACommand())
            {
                command.Connection = UserContext.Instance.SDAConnection;
                command.Transaction = UserContext.Instance.SDATransaction;
                command.CommandType = CommandType.StoredProcedure;
                command.CommandText = "uspGetSZMKOsztalyokEugyintezes";

                command.Parameters.Add("pGondviseloKretaAzonosito", gondviseloKretaAzonosito);

                var dataSet = new DataSet();
                using (var sdaDataAdapter = new SDADataAdapter())
                {
                    sdaDataAdapter.SelectCommand = command;
                    sdaDataAdapter.Fill(dataSet);
                }

                return dataSet;
            }
        }

        public DataSet GetAktualisGondviseloCimek(int gondviseloKretaAzonosito, int tanevId)
        {
            using (var command = new SDACommand())
            {
                command.Connection = UserContext.Instance.SDAConnection;
                command.Transaction = UserContext.Instance.SDATransaction;
                command.CommandType = CommandType.StoredProcedure;
                command.CommandText = "uspGetAktualisGondviseloCimekEugyintezes";

                command.Parameters.Add("pTanevId", tanevId);
                command.Parameters.Add("pGondviseloId", gondviseloKretaAzonosito);

                var dataSet = new DataSet();
                using (var sdaDataAdapter = new SDADataAdapter())
                {
                    sdaDataAdapter.SelectCommand = command;
                    sdaDataAdapter.Fill(dataSet);
                }

                return dataSet;
            }
        }

        public DataSet GetFelhasznaloCimek(string kretaIntezmenyAzonosito, int felhasznaloKretaAzonosito)
        {
            int intezmenyId = GetIntezmenyId(kretaIntezmenyAzonosito);

            using (var command = new SDACommand())
            {
                command.Connection = UserContext.Instance.SDAConnection;
                command.Transaction = UserContext.Instance.SDATransaction;
                command.CommandType = CommandType.StoredProcedure;
                command.CommandText = "uspGetFelhasznaloCimekEugyintezes";

                command.Parameters.Add("pIntezmenyId", intezmenyId);
                command.Parameters.Add("pFelhasznaloid", felhasznaloKretaAzonosito);

                var dataSet = new DataSet();
                using (var sdaDataAdapter = new SDADataAdapter())
                {
                    sdaDataAdapter.SelectCommand = command;
                    sdaDataAdapter.Fill(dataSet);
                }

                return dataSet;
            }
        }

        public DataSet GetFelhasznaloCimek(int felhasznaloKretaAzonosito, int tanevId)
        {
            using (var command = new SDACommand())
            {
                command.Connection = UserContext.Instance.SDAConnection;
                command.Transaction = UserContext.Instance.SDATransaction;
                command.CommandType = CommandType.StoredProcedure;
                command.CommandText = "uspGetFelhasznaloCimekByTanevEugyintezes";

                command.Parameters.Add("pTanevId", tanevId);
                command.Parameters.Add("pFelhasznaloId", felhasznaloKretaAzonosito);

                var dataSet = new DataSet();
                using (var sdaDataAdapter = new SDADataAdapter())
                {
                    sdaDataAdapter.SelectCommand = command;
                    sdaDataAdapter.Fill(dataSet);
                }

                return dataSet;
            }
        }

        public DataSet GetCim(int cimKretaAzonosito, int tanevId)
        {

            using (var command = new SDACommand())
            {
                command.Connection = UserContext.Instance.SDAConnection;
                command.Transaction = UserContext.Instance.SDATransaction;
                command.CommandType = CommandType.StoredProcedure;
                command.CommandText = "uspGetCimByIdAndTanevEugyintezes";

                command.Parameters.Add("pId", cimKretaAzonosito);
                command.Parameters.Add("pTanevId", tanevId);

                var dataSet = new DataSet();
                using (var sdaDataAdapter = new SDADataAdapter())
                {
                    sdaDataAdapter.SelectCommand = command;
                    sdaDataAdapter.Fill(dataSet);
                }

                return dataSet;
            }
        }

        public DataSet GetGyerekemOsztalyaBankszamlaszam(int gondviseloKretaAzonosito)
        {
            using (var command = new SDACommand())
            {
                command.Connection = UserContext.Instance.SDAConnection;
                command.Transaction = UserContext.Instance.SDATransaction;
                command.CommandType = CommandType.StoredProcedure;
                command.CommandText = "uspGetGyerekemOsztalyaBankszamlaszamEugyintezes";

                command.Parameters.Add("pGondviseloId", gondviseloKretaAzonosito);
                command.Parameters.Add("pOktNevKatTipus", (int)OktNevelesiKategoriaEnum.NevelesOktatas);

                var dataSet = new DataSet();
                using (var sdaDataAdapter = new SDADataAdapter())
                {
                    sdaDataAdapter.SelectCommand = command;
                    sdaDataAdapter.Fill(dataSet);
                }

                return dataSet;
            }
        }

        public DataSet GetTanarok(int? tanevKretaAzonosito)
        {
            var sqlParams = new List<CommandParameter> { };
            var commandText =
                $@"
                    SELECT DISTINCT
                      Alkalmazott.ID AS KretaAzonosito
                      ,Felhasznalo.C_NYOMTATASINEV AS Nev
                      ,Felhasznalo.C_OKTATASIAZONOSITO AS OktatasiAzonosito
                      ,Felhasznalo.C_EGYEDIAZONOSITO AS EgyediAzonosito
                        ,Felhasznalo.C_IDPEGYEDIAZONOSITO AS IdpEgyediAzonosito
                      ,MunkaugyiAdatok.C_VEZETOIORASZAMOK AS Titulus
                      ,IIF(MunkaugyiAdatok.C_VEZETOIORASZAMOK NOT IN (6571 /*Nincs, DictionaryItemBase*/, 6578 /*GyakorlatiOktatasvezeto, DictionaryItemBase*/), 1, 0) AS IsAlairo
                      ,IIF(Alkalmazott.TOROLT = 'T',1,0) as IsTorolt
                    FROM T_ALKALMAZOTT_OSSZES AS Alkalmazott
                    INNER JOIN T_FELHASZNALO_OSSZES Felhasznalo ON Alkalmazott.ID = Felhasznalo.ID
                    INNER JOIN (
                        SELECT
                        MunkaugyiAdatok.C_ALKALMAZOTTID
                        ,MunkaugyiAdatok.C_MUNKAKORTIPUSA
                        ,MunkaugyiAdatok.C_VEZETOIORASZAMOK
                            ,mkt.C_ALKALMAZOTTMUNKAKORTIPUSID
                        FROM T_MUNKAUGYIADATOK_OSSZES MunkaugyiAdatok
                        JOIN T_MUNKAKORTIPUS_OSSZES mkt on mkt.ID = MunkaugyiAdatok.C_MUNKAKORTIPUSA and mkt.C_ALINTEZMENYID = MunkaugyiAdatok.C_INTEZMENYID AND mkt.C_ALTANEVID = MunkaugyiAdatok.C_TANEVID
                        WHERE
                        CONVERT(date, GETDATE()) BETWEEN CONVERT(date, ISNULL(MunkaugyiAdatok.C_ALKALMAZASKEZDETE, GETDATE())) AND CONVERT(date, ISNULL(MunkaugyiAdatok.C_ALKALMAZASMEGSZUNESE, GETDATE()))
                        AND MunkaugyiAdatok.C_MUNKAKORTIPUSA NOT IN (
                          SELECT
                            JSON_VALUE(VALUE,'$.Value')
                          FROM OPENJSON((
                            SELECT RendszerBeallitas.C_ERTEK
                            FROM T_RENDSZERBEALLITAS RendszerBeallitas
                            WHERE RendszerBeallitas.C_BEALLITASTIPUS = 5441
                            AND RendszerBeallitas.TOROLT = 'F'),'$.Options')
                          WHERE
                            JSON_VALUE(VALUE,'$.Selected') = 'true')
                        OR MunkaugyiAdatok.C_MUNKAKORTIPUSA = 6710 /*Hitoktató*/
                        AND MunkaugyiAdatok.C_BETOLTETLENALLASHELY = 'F') MunkaugyiAdatok ON MunkaugyiAdatok.C_ALKALMAZOTTID = Alkalmazott.ID
                    INNER JOIN T_TANEV_OSSZES tanev ON tanev.ID = Alkalmazott.C_ALTANEVID AND tanev.TOROLT = 'F'
                    WHERE
                        Alkalmazott.TOROLT = 'F'
                      AND (MunkaugyiAdatok.C_ALKALMAZOTTMUNKAKORTIPUSID = 8384 /*Tanár*/
                            OR EXISTS (
                                SELECT TOP 1 1
                                FROM T_FOGLALKOZAS_OSSZES ttf
                                WHERE ttf.C_TANARID = Alkalmazott.ID AND ttf.TOROLT = 'F'
                            )
                        )
                ";

            if (tanevKretaAzonosito.HasValue)
            {
                commandText += @" AND Alkalmazott.C_ALTANEVID = @TanevId ";
                sqlParams.Add(new CommandParameter("TanevId", tanevKretaAzonosito));
            }
            else
            {
                commandText += @" AND tanev.C_AKTIV = 'T' ";
            }

            commandText += @" ORDER BY Felhasznalo.C_NYOMTATASINEV";

            var ds = GetData(commandText, sqlParams, dictionaryItemColumns: "Titulus");
            return ds;
        }

        public DataSet GetNOKSAlkalmazottak(int? tanevKretaAzonosito)
        {
            var sqlParams = new List<CommandParameter> { };
            var commandText =
                $@"
                    SELECT DISTINCT
                      Alkalmazott.ID AS KretaAzonosito
                      ,Felhasznalo.C_NYOMTATASINEV AS Nev
                      ,Felhasznalo.C_OKTATASIAZONOSITO AS OktatasiAzonosito
                      ,Felhasznalo.C_EGYEDIAZONOSITO AS EgyediAzonosito
                        ,Felhasznalo.C_IDPEGYEDIAZONOSITO AS IdpEgyediAzonosito
                      ,MunkaugyiAdatok.C_VEZETOIORASZAMOK AS Titulus
                      ,IIF(MunkaugyiAdatok.C_VEZETOIORASZAMOK NOT IN (6571 /*Nincs, DictionaryItemBase*/, 6578 /*GyakorlatiOktatasvezeto, DictionaryItemBase*/), 1, 0) AS IsAlairo
                      ,IIF(Alkalmazott.TOROLT = 'T',1,0) as IsTorolt
                    FROM T_ALKALMAZOTT_OSSZES AS Alkalmazott
                    INNER JOIN T_FELHASZNALO_OSSZES Felhasznalo ON Alkalmazott.ID = Felhasznalo.ID
                    INNER JOIN (
                        SELECT
                        MunkaugyiAdatok.C_ALKALMAZOTTID
                        ,MunkaugyiAdatok.C_MUNKAKORTIPUSA
                        ,MunkaugyiAdatok.C_VEZETOIORASZAMOK
                            ,mkt.C_ALKALMAZOTTMUNKAKORTIPUSID
                        FROM T_MUNKAUGYIADATOK_OSSZES MunkaugyiAdatok
                        JOIN T_MUNKAKORTIPUS_OSSZES mkt on mkt.ID = MunkaugyiAdatok.C_MUNKAKORTIPUSA and mkt.C_ALINTEZMENYID = MunkaugyiAdatok.C_INTEZMENYID AND mkt.C_ALTANEVID = MunkaugyiAdatok.C_TANEVID
                        WHERE
                            CONVERT(date, GETDATE()) BETWEEN CONVERT(date, ISNULL(MunkaugyiAdatok.C_ALKALMAZASKEZDETE, GETDATE())) AND CONVERT(date, ISNULL(MunkaugyiAdatok.C_ALKALMAZASMEGSZUNESE, GETDATE()))
                        AND MunkaugyiAdatok.C_MUNKAKORTIPUSA NOT IN (
                          SELECT
                            JSON_VALUE(VALUE,'$.Value')
                          FROM OPENJSON((
                            SELECT RendszerBeallitas.C_ERTEK
                            FROM T_RENDSZERBEALLITAS RendszerBeallitas
                            WHERE RendszerBeallitas.C_BEALLITASTIPUS = 5441
                            AND RendszerBeallitas.TOROLT = 'F'),'$.Options')
                          WHERE
                            JSON_VALUE(VALUE,'$.Selected') = 'true')
                        OR MunkaugyiAdatok.C_MUNKAKORTIPUSA = 6710 /*Hitoktató*/
                        AND MunkaugyiAdatok.C_BETOLTETLENALLASHELY = 'F') MunkaugyiAdatok ON MunkaugyiAdatok.C_ALKALMAZOTTID = Alkalmazott.ID
                    WHERE
                      MunkaugyiAdatok.C_ALKALMAZOTTMUNKAKORTIPUSID = 8385 /*NOKS*/
                ";

            if (tanevKretaAzonosito.HasValue)
            {
                commandText += @" AND Alkalmazott.C_ALTANEVID = @TanevId ";
                sqlParams.Add(new CommandParameter("TanevId", tanevKretaAzonosito));
            }

            commandText += @" ORDER BY Felhasznalo.C_NYOMTATASINEV";

            var ds = GetData(commandText, sqlParams, dictionaryItemColumns: "Titulus");
            return ds;
        }

        public DataSet GetEgyebAlkalmazottak(int? tanevKretaAzonosito)
        {
            var sqlParams = new List<CommandParameter> { };
            var commandText =
                $@"
                    SELECT DISTINCT
                      Alkalmazott.ID AS KretaAzonosito
                      ,Felhasznalo.C_NYOMTATASINEV AS Nev
                      ,Felhasznalo.C_OKTATASIAZONOSITO AS OktatasiAzonosito
                      ,Felhasznalo.C_EGYEDIAZONOSITO AS EgyediAzonosito
                        ,Felhasznalo.C_IDPEGYEDIAZONOSITO AS IdpEgyediAzonosito
                      ,MunkaugyiAdatok.C_VEZETOIORASZAMOK AS Titulus
                      ,IIF(MunkaugyiAdatok.C_VEZETOIORASZAMOK NOT IN (6571 /*Nincs, DictionaryItemBase*/, 6578 /*GyakorlatiOktatasvezeto, DictionaryItemBase*/), 1, 0) AS IsAlairo
                      ,IIF(Alkalmazott.TOROLT = 'T',1,0) as IsTorolt
                    FROM T_ALKALMAZOTT_OSSZES AS Alkalmazott
                    INNER JOIN T_FELHASZNALO_OSSZES Felhasznalo ON Alkalmazott.ID = Felhasznalo.ID
                    INNER JOIN (
                        SELECT
                        MunkaugyiAdatok.C_ALKALMAZOTTID
                        ,MunkaugyiAdatok.C_MUNKAKORTIPUSA
                        ,MunkaugyiAdatok.C_VEZETOIORASZAMOK
                            ,mkt.C_ALKALMAZOTTMUNKAKORTIPUSID
                        FROM T_MUNKAUGYIADATOK_OSSZES MunkaugyiAdatok
                        JOIN T_MUNKAKORTIPUS_OSSZES mkt on mkt.ID = MunkaugyiAdatok.C_MUNKAKORTIPUSA and mkt.C_ALINTEZMENYID = MunkaugyiAdatok.C_INTEZMENYID AND mkt.C_ALTANEVID = MunkaugyiAdatok.C_TANEVID
                        WHERE
                        CONVERT(date, GETDATE()) BETWEEN CONVERT(date, ISNULL(MunkaugyiAdatok.C_ALKALMAZASKEZDETE, GETDATE())) AND CONVERT(date, ISNULL(MunkaugyiAdatok.C_ALKALMAZASMEGSZUNESE, GETDATE()))";

            if (tanevKretaAzonosito.HasValue)
                commandText += @" AND MunkaugyiAdatok.C_TANEVID = @TanevId ";

            commandText += $@"
                        AND MunkaugyiAdatok.C_MUNKAKORTIPUSA NOT IN (
                          SELECT
                            JSON_VALUE(VALUE,'$.Value')
                          FROM OPENJSON((
                            SELECT RendszerBeallitas.C_ERTEK
                            FROM T_RENDSZERBEALLITAS RendszerBeallitas
                            WHERE RendszerBeallitas.C_BEALLITASTIPUS = 5441
                            AND RendszerBeallitas.TOROLT = 'F'),'$.Options')
                          WHERE
                            JSON_VALUE(VALUE,'$.Selected') = 'true')
                        OR MunkaugyiAdatok.C_MUNKAKORTIPUSA = 6710 /*Hitoktató*/
                        AND MunkaugyiAdatok.C_BETOLTETLENALLASHELY = 'F') MunkaugyiAdatok ON MunkaugyiAdatok.C_ALKALMAZOTTID = Alkalmazott.ID
                    WHERE
                      (MunkaugyiAdatok.C_ALKALMAZOTTMUNKAKORTIPUSID = 8386 /*Egyéb*/ OR MunkaugyiAdatok.C_ALKALMAZOTTMUNKAKORTIPUSID IS NULL)
                ";

            if (tanevKretaAzonosito.HasValue)
            {
                commandText += @" AND Alkalmazott.C_ALTANEVID = @TanevId ";
                sqlParams.Add(new CommandParameter("TanevId", tanevKretaAzonosito));
            }

            commandText += @" ORDER BY Felhasznalo.C_NYOMTATASINEV";

            var ds = GetData(commandText, sqlParams, dictionaryItemColumns: "Titulus");
            return ds;
        }

        public DataSet GetOsztalyfonokok(int? tanevKretaAzonosito)
        {
            var commandText =
                $@"SELECT
                      OsztalyFonok.KretaAzonosito
                     ,OsztalyFonok.Nev
                     ,OsztalyFonok.OktatasiAzonosito
                     ,OsztalyFonok.OsztalyKretaAzonosito
                     ,OsztalyFonok.Osztaly
                     ,OsztalyFonok.IsOsztalyfonok
                     ,OsztalyFonok.IsOsztalyfonokHelyettes
                     ,OsztalyFonok.EgyediAzonosito
                     ,OsztalyFonok.IdpEgyediAzonosito
                     ,OsztalyFonok.Titulus
                   FROM (
                     SELECT
                        Alkalmazott.ID AS KretaAzonosito
                       ,Felhasznalo.C_NYOMTATASINEV AS Nev
                       ,Felhasznalo.C_OKTATASIAZONOSITO AS OktatasiAzonosito
                       ,Osztaly.ID AS OsztalyKretaAzonosito
                       ,OsztalyCsoport.C_NEV AS Osztaly
                       ,1 AS IsOsztalyfonok
                       ,0 AS IsOsztalyfonokHelyettes
                       ,Felhasznalo.C_EGYEDIAZONOSITO AS EgyediAzonosito
                       ,Felhasznalo.C_IDPEGYEDIAZONOSITO AS IdpEgyediAzonosito
                       ,MunkaugyiAdatok.C_VEZETOIORASZAMOK as Titulus
                       ,Alkalmazott.C_ALTANEVID as Tanev
                     FROM T_ALKALMAZOTT AS Alkalmazott
                     INNER JOIN T_FELHASZNALO Felhasznalo ON Alkalmazott.ID = Felhasznalo.ID AND Felhasznalo.TOROLT = 'F'
                     INNER JOIN T_OSZTALY Osztaly ON Osztaly.C_OSZTALYFONOKID = Alkalmazott.ID AND Osztaly.TOROLT = 'F'
                     INNER JOIN T_OSZTALYCSOPORT OsztalyCsoport ON Osztaly.ID = OsztalyCsoport.ID
                       AND OsztalyCsoport.TOROLT = 'F'
                     INNER JOIN T_MUNKAUGYIADATOK MunkaugyiAdatok ON MunkaugyiAdatok.C_ALKALMAZOTTID = Alkalmazott.ID
                       AND MunkaugyiAdatok.TOROLT = 'F'
                       AND MunkaugyiAdatok.C_BETOLTETLENALLASHELY = 'F'
                       AND CONVERT(date, GETDATE()) BETWEEN CONVERT(date, ISNULL(MunkaugyiAdatok.C_ALKALMAZASKEZDETE, GETDATE())) AND CONVERT(date, ISNULL(MunkaugyiAdatok.C_ALKALMAZASMEGSZUNESE, GETDATE()))
                     WHERE Alkalmazott.TOROLT = 'F'
                   UNION ALL
                     SELECT
                        Alkalmazott.ID AS KretaAzonosito
                       ,Felhasznalo.C_NYOMTATASINEV AS Nev
                       ,Felhasznalo.C_OKTATASIAZONOSITO AS OktatasiAzonosito
                       ,Osztaly.ID AS OsztalyKretaAzonosito
                       ,OsztalyCsoport.C_NEV AS Osztaly
                       ,0 AS IsOsztalyfonok
                       ,1 AS IsOsztalyfonokHelyettes
                       ,Felhasznalo.C_EGYEDIAZONOSITO AS EgyediAzonosito
                       ,Felhasznalo.C_IDPEGYEDIAZONOSITO AS IdpEgyediAzonosito
                       ,MunkaugyiAdatok.C_VEZETOIORASZAMOK as Titulus
                       ,Alkalmazott.C_ALTANEVID as Tanev
                     FROM T_ALKALMAZOTT AS Alkalmazott
                     INNER JOIN T_FELHASZNALO Felhasznalo ON Alkalmazott.ID = Felhasznalo.ID AND Felhasznalo.TOROLT = 'F'
                     INNER JOIN T_OSZTALY Osztaly ON Osztaly.C_OFOHELYETTESID = Alkalmazott.ID AND Osztaly.TOROLT = 'F'
                     INNER JOIN T_OSZTALYCSOPORT OsztalyCsoport ON Osztaly.ID = OsztalyCsoport.ID
                       AND OsztalyCsoport.TOROLT = 'F'
                     INNER JOIN T_MUNKAUGYIADATOK MunkaugyiAdatok ON MunkaugyiAdatok.C_ALKALMAZOTTID = Alkalmazott.ID
                       AND MunkaugyiAdatok.TOROLT = 'F'
                       AND MunkaugyiAdatok.C_BETOLTETLENALLASHELY = 'F'
                       AND CONVERT(date, GETDATE()) BETWEEN CONVERT(date, ISNULL(MunkaugyiAdatok.C_ALKALMAZASKEZDETE, GETDATE())) AND CONVERT(date, ISNULL(MunkaugyiAdatok.C_ALKALMAZASMEGSZUNESE, GETDATE()))
                     WHERE Alkalmazott.TOROLT = 'F'
                   ) OsztalyFonok";

            var sqlParams = new List<CommandParameter>();

            if (tanevKretaAzonosito.HasValue)
            {
                commandText += @" WHERE OsztalyFonok.Tanev = @TanevId ";
                sqlParams.Add(new CommandParameter("TanevId", tanevKretaAzonosito));
            }

            commandText += @" ORDER BY OsztalyFonok.Nev";

            var ds = GetData(commandText, sqlParams, dictionaryItemColumns: "Titulus");
            return ds;
        }

        public DataSet GetIgazgatosagiAlkalmazottak(int? tanevKretaAzonosito)
        {
            var commandText =
                $@"SELECT
                      Alkalmazott.ID AS KretaAzonosito
                     ,Felhasznalo.C_NYOMTATASINEV AS Nev
                     ,Felhasznalo.C_OKTATASIAZONOSITO AS OktatasiAzonosito
                     ,MunkaugyiAdatok.C_VEZETOIORASZAMOK AS Titulus
                     ,IIF(MunkaugyiAdatok.C_VEZETOIORASZAMOK NOT IN (6571 /*Nincs, DictionaryItemBase*/, 6578 /*GyakorlatiOktatasvezeto, DictionaryItemBase*/), 1, 0) AS IsAlairo
                     ,Osztaly.ID AS OsztalyKretaAzonosito
                     ,Osztaly.Osztaly
                     ,OsztalyHelyettes.ID AS OsztalyHelyettesKretaAzonosito
                     ,OsztalyHelyettes.Osztaly AS OsztalyHelyettes
                     ,IIF(Osztaly.OsztalyfonokId = Alkalmazott.ID, 1, 0) AS IsOsztalyfonok
                     ,IIF(OsztalyHelyettes.OsztalyfonokHelyettesId = Alkalmazott.ID, 1, 0) AS IsOsztalyfonokHelyettes
                     ,Felhasznalo.C_EGYEDIAZONOSITO AS EgyediAzonosito
                     ,Felhasznalo.C_IDPEGYEDIAZONOSITO AS IdpEgyediAzonosito
                     ,IIF(Alkalmazott.TOROLT = 'T',1,0) as IsTorolt
                   FROM T_ALKALMAZOTT_OSSZES AS Alkalmazott
                     INNER JOIN T_FELHASZNALO_OSSZES Felhasznalo ON Alkalmazott.ID = Felhasznalo.ID
                     INNER JOIN T_MUNKAUGYIADATOK_OSSZES MunkaugyiAdatok ON MunkaugyiAdatok.C_ALKALMAZOTTID = Alkalmazott.ID AND MunkaugyiAdatok.C_BETOLTETLENALLASHELY = 'F'
                        AND CONVERT(date, GETDATE()) BETWEEN CONVERT(date, ISNULL(MunkaugyiAdatok.C_ALKALMAZASKEZDETE, GETDATE())) AND CONVERT(date, ISNULL(MunkaugyiAdatok.C_ALKALMAZASMEGSZUNESE, GETDATE()))
                     LEFT JOIN (SELECT
                                   OsztalyCsoport.ID
                                  ,OsztalyCsoport.C_NEV AS Osztaly
                                  ,Osztaly.C_OSZTALYFONOKID AS OsztalyfonokId
                                FROM T_OSZTALYCSOPORT OsztalyCsoport
                                INNER JOIN T_OSZTALY Osztaly ON Osztaly.ID = OsztalyCsoport.ID
                                  AND Osztaly.TOROLT = 'F'
                                WHERE OsztalyCsoport.TOROLT = 'F' AND OsztalyCsoport.C_FELADATKATEGORIAID = @OktNevKatTipus) Osztaly ON Osztaly.OsztalyfonokId = Alkalmazott.ID
                     LEFT JOIN (SELECT
                                   OsztalyCsoport.ID
                                  ,OsztalyCsoport.C_NEV AS Osztaly
                                  ,Osztaly.C_OFOHELYETTESID AS OsztalyfonokHelyettesId
                                FROM T_OSZTALYCSOPORT OsztalyCsoport
                                INNER JOIN T_OSZTALY Osztaly ON Osztaly.ID = OsztalyCsoport.ID
                                  AND Osztaly.TOROLT = 'F'
                                WHERE OsztalyCsoport.TOROLT = 'F' AND OsztalyCsoport.C_FELADATKATEGORIAID = @OktNevKatTipus) OsztalyHelyettes ON OsztalyHelyettes.OsztalyfonokHelyettesId = Alkalmazott.ID
                   WHERE MunkaugyiAdatok.C_VEZETOIORASZAMOK != 6571 
                ";

            var sqlParams = new List<CommandParameter> { new CommandParameter("OktNevKatTipus", (int)OktNevelesiKategoriaEnum.NevelesOktatas) };

            if (tanevKretaAzonosito.HasValue)
            {
                commandText += @" AND Alkalmazott.C_ALTANEVID = @TanevId ";
                sqlParams.Add(new CommandParameter("TanevId", tanevKretaAzonosito));
            }

            commandText += @" ORDER BY Felhasznalo.C_NYOMTATASINEV";

            var ds = GetData(commandText, sqlParams, dictionaryItemColumns: "Titulus");
            return ds;
        }

        public DataSet GetKretaAdminisztratorok(int? tanevKretaAzonosito)
        {
            var commandText =
                $@"SELECT
                      Alkalmazott.ID AS KretaAzonosito
                     ,Felhasznalo.C_NYOMTATASINEV AS Nev
                     ,Felhasznalo.C_OKTATASIAZONOSITO AS OktatasiAzonosito
                     ,Osztaly.ID AS OsztalyKretaAzonosito
                     ,Osztaly.Osztaly
                     ,OsztalyHelyettes.ID AS OsztalyHelyettesKretaAzonosito
                     ,OsztalyHelyettes.Osztaly AS OsztalyHelyettes
                     ,IIF(Osztaly.OsztalyfonokId = Alkalmazott.ID, 1, 0) AS IsOsztalyfonok
                     ,IIF(OsztalyHelyettes.OsztalyfonokHelyettesId = Alkalmazott.ID, 1, 0) AS IsOsztalyfonokHelyettes
                     ,Felhasznalo.C_EGYEDIAZONOSITO AS EgyediAzonosito
                     ,Felhasznalo.C_IDPEGYEDIAZONOSITO AS IdpEgyediAzonosito
                     ,MunkaugyiAdatok.C_VEZETOIORASZAMOK as Titulus
                     ,IIF(MunkaugyiAdatok.C_VEZETOIORASZAMOK NOT IN (6571 /*Nincs, DictionaryItemBase*/, 6578 /*GyakorlatiOktatasvezeto, DictionaryItemBase*/), 1, 0) AS IsAlairo
                     ,IIF(Alkalmazott.TOROLT = 'T',1,0) as IsTorolt
                   FROM T_ALKALMAZOTT_OSSZES AS Alkalmazott
                     INNER JOIN T_FELHASZNALO_OSSZES Felhasznalo ON Alkalmazott.ID = Felhasznalo.ID
                     LEFT JOIN (SELECT
                                   OsztalyCsoport.ID
                                  ,OsztalyCsoport.C_NEV AS Osztaly
                                  ,Osztaly.C_OSZTALYFONOKID AS OsztalyfonokId
                                FROM T_OSZTALYCSOPORT OsztalyCsoport
                                INNER JOIN T_OSZTALY Osztaly ON Osztaly.ID = OsztalyCsoport.ID
                                  AND Osztaly.TOROLT = 'F'
                                WHERE OsztalyCsoport.TOROLT = 'F' AND OsztalyCsoport.C_FELADATKATEGORIAID = @OktNevKatTipus) Osztaly ON Osztaly.OsztalyfonokId = Alkalmazott.ID
                     LEFT JOIN (SELECT
                                   OsztalyCsoport.ID
                                  ,OsztalyCsoport.C_NEV AS Osztaly
                                  ,Osztaly.C_OFOHELYETTESID AS OsztalyfonokHelyettesId
                                FROM T_OSZTALYCSOPORT OsztalyCsoport
                                INNER JOIN T_OSZTALY Osztaly ON Osztaly.ID = OsztalyCsoport.ID
                                  AND Osztaly.TOROLT = 'F'
                                WHERE OsztalyCsoport.TOROLT = 'F' AND OsztalyCsoport.C_FELADATKATEGORIAID = @OktNevKatTipus) OsztalyHelyettes ON OsztalyHelyettes.OsztalyfonokHelyettesId = Alkalmazott.ID
                     INNER JOIN T_MUNKAUGYIADATOK_OSSZES MunkaugyiAdatok ON MunkaugyiAdatok.C_ALKALMAZOTTID = Alkalmazott.ID AND MunkaugyiAdatok.C_BETOLTETLENALLASHELY = 'F'
                        AND CONVERT(date, GETDATE()) BETWEEN CONVERT(date, ISNULL(MunkaugyiAdatok.C_ALKALMAZASKEZDETE, GETDATE())) AND CONVERT(date, ISNULL(MunkaugyiAdatok.C_ALKALMAZASMEGSZUNESE, GETDATE()))
                   WHERE
                     EXISTS (SELECT *
                                FROM T_FELHASZNALO_SZEREPKOR FelhasznaloSzerepkor
                                INNER JOIN T_SZEREPKOR Szerepkor ON Szerepkor.ID = FelhasznaloSzerepkor.C_SZEREPKORID
                                AND Szerepkor.C_SZEREPKORTIPUS = 1758 /*Adminisztrátor, DictionaryItemBase*/
                                WHERE C_FELHASZNALOID = Alkalmazott.ID)";

            var sqlParams = new List<CommandParameter> { new CommandParameter("OktNevKatTipus", (int)OktNevelesiKategoriaEnum.NevelesOktatas) };

            if (tanevKretaAzonosito.HasValue)
            {
                commandText += @" AND Alkalmazott.C_ALTANEVID = @TanevId ";
                sqlParams.Add(new CommandParameter("TanevId", tanevKretaAzonosito));
            }

            var ds = GetData(commandText, sqlParams, dictionaryItemColumns: "Titulus");
            return ds;
        }

        public DataSet GetOsztalyGondviselok(int osztalyKretaAzonosito, int tanevId)
        {
            using (var command = new SDACommand())
            {
                command.Connection = UserContext.Instance.SDAConnection;
                command.Transaction = UserContext.Instance.SDATransaction;
                command.CommandType = CommandType.StoredProcedure;
                command.CommandText = "uspGetOsztalyGondviselokEugyintezes";

                command.Parameters.Add("pTanevId", tanevId);
                command.Parameters.Add("pOsztalyCsoportId", osztalyKretaAzonosito);

                var dataSet = new DataSet();
                using (var sdaDataAdapter = new SDADataAdapter())
                {
                    sdaDataAdapter.SelectCommand = command;
                    sdaDataAdapter.Fill(dataSet);
                }

                return dataSet;
            }
        }

        public DataSet GetTanoraiCsoportGondviselok(int tanoraiCsoportKretaAzonosito, int tanevId)
        {
            using (var command = new SDACommand())
            {
                command.Connection = UserContext.Instance.SDAConnection;
                command.Transaction = UserContext.Instance.SDATransaction;
                command.CommandType = CommandType.StoredProcedure;
                command.CommandText = "uspGetTanoraiCsoportGondviselokEugyintezes";

                command.Parameters.Add("pTanevId", tanevId);
                command.Parameters.Add("pOsztalyCsoportId", tanoraiCsoportKretaAzonosito);

                var dataSet = new DataSet();
                using (var sdaDataAdapter = new SDADataAdapter())
                {
                    sdaDataAdapter.SelectCommand = command;
                    sdaDataAdapter.Fill(dataSet);
                }

                return dataSet;
            }
        }

        public DataSet GetAlkalmazottAdatok(int kretaFelhasznaloAzonosito, int? tanevKretaAzonosito)
        {
            if (!tanevKretaAzonosito.HasValue)
            {
                tanevKretaAzonosito = GetTanevId(kretaFelhasznaloAzonosito);
            }

            using (var command = new SDACommand())
            {
                command.Connection = UserContext.Instance.SDAConnection;
                command.Transaction = UserContext.Instance.SDATransaction;
                command.CommandType = CommandType.StoredProcedure;
                command.CommandText = "uspGetAlkalmazottAdatokEugyintezes";

                command.Parameters.Add("pFelhasznaloId", kretaFelhasznaloAzonosito);
                command.Parameters.Add("pSzerepkorTipusEnumNaplo", (int)SzerepkorTipusEnum.Naplo);
                command.Parameters.Add("pOktNevKatTipusNevOkt", (int)OktNevelesiKategoriaEnum.NevelesOktatas);
                command.Parameters.Add("pTanevId", tanevKretaAzonosito);

                var dataSet = new DataSet();
                using (var sdaDataAdapter = new SDADataAdapter())
                {
                    sdaDataAdapter.SelectCommand = command;
                    sdaDataAdapter.Fill(dataSet);
                }

                SetDNAME(dataSet.Tables[0], "Titulus");
                return dataSet;
            }

        }

        public DataSet GetGondviseloAdatok(int kretaFelhasznaloAzonosito)
        {
            int tanevKretaAzonosito = GetGondviseloTanevId(kretaFelhasznaloAzonosito);

            using (var command = new SDACommand())
            {
                command.Connection = UserContext.Instance.SDAConnection;
                command.Transaction = UserContext.Instance.SDATransaction;
                command.CommandType = CommandType.StoredProcedure;
                command.CommandText = "uspGetGondviseloAdatokEugyintezes";

                command.Parameters.Add("pFelhasznaloId", kretaFelhasznaloAzonosito);
                command.Parameters.Add("pSzerepkorTipusEnumNaplo", (int)SzerepkorTipusEnum.Naplo);
                command.Parameters.Add("pOktNevKatTipusNevOkt", (int)OktNevelesiKategoriaEnum.NevelesOktatas);
                command.Parameters.Add("pTanevId", tanevKretaAzonosito);

                var dataSet = new DataSet();
                using (var sdaDataAdapter = new SDADataAdapter())
                {
                    sdaDataAdapter.SelectCommand = command;
                    sdaDataAdapter.Fill(dataSet);
                }

                return dataSet;
            }
        }

        public DataSet GetSZMKKepviselok(int tanevId)
        {
            using (var command = new SDACommand())
            {
                command.Connection = UserContext.Instance.SDAConnection;
                command.Transaction = UserContext.Instance.SDATransaction;
                command.CommandType = CommandType.StoredProcedure;
                command.CommandText = "uspGetSZMKKepviselokEugyintezes";

                command.Parameters.Add("pOktNevKatTipusNevOkt", SDADBType.Int).Value = (int)OktNevelesiKategoriaEnum.NevelesOktatas;
                command.Parameters.Add("pTanevId", SDADBType.Int).Value = tanevId;

                var dataSet = new DataSet();
                using (var sdaDataAdapter = new SDADataAdapter())
                {
                    sdaDataAdapter.SelectCommand = command;
                    sdaDataAdapter.Fill(dataSet);
                }

                return dataSet;
            }
        }

        public DataSet GetTanuloAdatokByKretaAzonosito(int kretaAzonosito)
        {
            using (var command = new SDACommand())
            {
                command.Connection = UserContext.Instance.SDAConnection;
                command.Transaction = UserContext.Instance.SDATransaction;
                command.CommandType = CommandType.StoredProcedure;
                command.CommandText = "uspGetTanuloAdatokByKretaAzonositoEugyintezes";

                command.Parameters.Add("pFelhasznaloId", kretaAzonosito);

                var dataSet = new DataSet();
                using (var sdaDataAdapter = new SDADataAdapter())
                {
                    sdaDataAdapter.SelectCommand = command;
                    sdaDataAdapter.Fill(dataSet);
                }

                return dataSet;
            }
        }

        public DataSet GetTanuloOsztalyfonok(string oktatasiAzonosito)
        {
            using (var command = new SDACommand())
            {
                command.Connection = UserContext.Instance.SDAConnection;
                command.Transaction = UserContext.Instance.SDATransaction;
                command.CommandType = CommandType.StoredProcedure;
                command.CommandText = "uspGetTanuloOsztalyfonokEugyintezes";

                command.Parameters.Add("pOktatasiAzonosito", oktatasiAzonosito);
                command.Parameters.Add("pOktNevKatTipus", (int)OktNevelesiKategoriaEnum.NevelesOktatas);

                var dataSet = new DataSet();
                using (var sdaDataAdapter = new SDADataAdapter())
                {
                    sdaDataAdapter.SelectCommand = command;
                    sdaDataAdapter.Fill(dataSet);
                }

                SetDNAME(dataSet.Tables[0], "Titulus");
                return dataSet;
            }
        }

        public DataSet GetEUgyintezokEsOsztalyfonokok()
        {
            using (var command = new SDACommand())
            {
                command.Connection = UserContext.Instance.SDAConnection;
                command.Transaction = UserContext.Instance.SDATransaction;
                command.CommandType = CommandType.StoredProcedure;
                command.CommandText = "uspGetEUgyintezokEsOsztalyfonokokEsHelyettesek";

                command.Parameters.Add("pEUgyintezoSzerepkorTipusId", (int)SzerepkorTipusEnum.eUgyintezo);
                var ds = new DataSet();

                using (var adapter = new SDADataAdapter())
                {
                    adapter.SelectCommand = command;
                    adapter.Fill(ds);
                }
                return ds;
            }
        }

        public DataSet GetFoglalhatoTermek(int tanevId)
        {
            using (var command = new SDACommand())
            {
                command.Connection = UserContext.Instance.SDAConnection;
                command.Transaction = UserContext.Instance.SDATransaction;
                command.CommandType = CommandType.StoredProcedure;
                command.CommandText = "uspGetFoglalhatoTermekEugyintezes";

                command.Parameters.Add("pTanevId", tanevId);

                var dataSet = new DataSet();
                using (var sdaDataAdapter = new SDADataAdapter())
                {
                    sdaDataAdapter.SelectCommand = command;
                    sdaDataAdapter.Fill(dataSet);
                }

                return dataSet;
            }
        }

        public DataSet GetFoglalhatoTermekElerhetosegei(int teremId)
        {
            using (var command = new SDACommand())
            {
                command.Connection = UserContext.Instance.SDAConnection;
                command.Transaction = UserContext.Instance.SDATransaction;
                command.CommandType = CommandType.StoredProcedure;
                command.CommandText = "uspGetFoglalhatoTermekElerhetosegeiEugyintezes";

                command.Parameters.Add("pTeremId", teremId);

                var dataSet = new DataSet();
                using (var sdaDataAdapter = new SDADataAdapter())
                {
                    sdaDataAdapter.SelectCommand = command;
                    sdaDataAdapter.Fill(dataSet);
                }

                return dataSet;
            }
        }

        public DataSet GetAdatszotarByTipus(int kretaAzonosito, GeneratedAdatszotarTipusEnum tipus, int tanevId)
        {
            using (var command = new SDACommand())
            {
                command.Connection = UserContext.Instance.SDAConnection;
                command.Transaction = UserContext.Instance.SDATransaction;
                command.CommandType = CommandType.StoredProcedure;
                command.CommandText = "uspGetAdatszotarByTipusEugyintezes";

                command.Parameters.Add("pTanevId", tanevId);
                command.Parameters.Add("pDictionaryId", kretaAzonosito);
                command.Parameters.Add("pDictionaryTypeId", tipus);

                var dataSet = new DataSet();
                using (var sdaDataAdapter = new SDADataAdapter())
                {
                    sdaDataAdapter.SelectCommand = command;
                    sdaDataAdapter.Fill(dataSet);
                }

                return dataSet;
            }
        }

        public DataSet GetAdatszotarakByTipus(GeneratedAdatszotarTipusEnum tipus, int tanevId)
        {
            using (var command = new SDACommand())
            {
                command.Connection = UserContext.Instance.SDAConnection;
                command.Transaction = UserContext.Instance.SDATransaction;
                command.CommandType = CommandType.StoredProcedure;
                command.CommandText = "uspGetAdatszotarakByTipusEugyintezes";

                command.Parameters.Add("pTanevId", tanevId);
                command.Parameters.Add("pDictionaryTypeId", tipus);

                var dataSet = new DataSet();
                using (var sdaDataAdapter = new SDADataAdapter())
                {
                    sdaDataAdapter.SelectCommand = command;
                    sdaDataAdapter.Fill(dataSet);
                }

                return dataSet;
            }
        }

        public DataSet GetTanitottOsztalyok(int alkalmazottKretaAzonosito)
        {
            using (var command = new SDACommand())
            {
                command.Connection = UserContext.Instance.SDAConnection;
                command.Transaction = UserContext.Instance.SDATransaction;
                command.CommandType = CommandType.StoredProcedure;
                command.CommandText = "uspGetTanitottOsztalyokEugyintezes";

                command.Parameters.Add("pAlkalmazottId", alkalmazottKretaAzonosito);

                var dataSet = new DataSet();
                using (var sdaDataAdapter = new SDADataAdapter())
                {
                    sdaDataAdapter.SelectCommand = command;
                    sdaDataAdapter.Fill(dataSet);
                }

                return dataSet;
            }
        }

        public DataSet GetOsztalyfonokoltOsztalyok(int alkalmazottKretaAzonosito)
        {
            using (var command = new SDACommand())
            {
                command.Connection = UserContext.Instance.SDAConnection;
                command.Transaction = UserContext.Instance.SDATransaction;
                command.CommandType = CommandType.StoredProcedure;
                command.CommandText = "uspGetOsztalyfonokoltOsztalyokEugyintezes";

                command.Parameters.Add("pAlkalmazottId", alkalmazottKretaAzonosito);

                var dataSet = new DataSet();
                using (var sdaDataAdapter = new SDADataAdapter())
                {
                    sdaDataAdapter.SelectCommand = command;
                    sdaDataAdapter.Fill(dataSet);
                }

                return dataSet;
            }
        }

        public DataSet GetBulkTanuloSzamlaAdatok(int osztalyCsoportKretaAzonosito, List<string> oktatasiAzonositok)
        {
            var commandParameters = new List<CommandParameter>()
            {
                new CommandParameter(nameof(osztalyCsoportKretaAzonosito), osztalyCsoportKretaAzonosito)
            };

            var inCommandParameter = new List<string>();

            foreach (var azonosito in oktatasiAzonositok)
            {
                var name = string.Format("pOktatasiAzonosito{0}", oktatasiAzonositok.IndexOf(azonosito));

                commandParameters.Add(new CommandParameter(name, azonosito));
                inCommandParameter.Add("@" + name);
            }

            var commandText = $@"SELECT
                                    Felhasznalo.C_OKTATASIAZONOSITO AS OktatasiAzonosito
                                   ,Felhasznalo.C_NYOMTATASINEV AS Nev
                                   ,Cim.ID AS KretaAzonosito
                                   ,Cim.C_ISOKOD AS OrszagISO
                                   ,ISNULL(Cim.C_ORSZAG, '') AS OrszagKretaAzonosito
                                   ,ISNULL(Cim.C_NAME, '') AS OrszagNev
                                   ,Cim.C_IRANYITOSZAM AS Iranyitoszam
                                   ,Cim.C_VAROS AS Helyseg
                                   ,Cim.C_KOZTERULET AS KozteruletNeve
                                   ,Cim.C_KOZTERULETJELLEGENEV AS KozteruletJellegeNev
                                   ,Cim.C_HAZSZAM AS Hazszam
                                   ,Cim.C_EMELET AS Emelet
                                   ,Cim.C_AJTO AS Ajto
                                   ,Felhasznalo.C_ADOAZONOSITOJEL AS Adoszam
                                   ,x.FunkcioTeruletSAPKod
                                 FROM T_FELHASZNALO Felhasznalo
                                 CROSS APPLY fnGetFelhaszaloCim(Felhasznalo.ID) Cim
                                 INNER JOIN T_TANULO Tanulo ON Tanulo.ID = Felhasznalo.ID
                                   AND Tanulo.TOROLT = 'F'
                                 LEFT JOIN (
                                    SELECT
                                         tcs.C_TANULOID as TId
                                        ,mh.C_FUNKCIOTERULET as FunkcioTeruletSAPKod
                                    FROM T_TANULOCSOPORT tcs
                                        INNER JOIN T_OSZTALY o ON o.ID = tcs.C_OSZTALYCSOPORTID AND o.TOROLT = 'F'
                                        INNER JOIN T_OSZTALYCSOPORT ocs on ocs.ID = o.ID AND ocs.TOROLT = 'F'
                                        INNER JOIN T_FELADATELLATASIHELY feh on feh.ID = ocs.C_FELADATELLATASIHELYID AND feh.TOROLT = 'F'
                                        INNER JOIN T_MUKODESIHELY mh on mh.ID = feh.C_MUKODESIHELYID AND mh.TOROLT = 'F'
                                    WHERE
                                        tcs.TOROLT = 'F' AND ocs.ID = @{nameof(osztalyCsoportKretaAzonosito)}
                                ) x ON x.TId = Tanulo.ID
                                 WHERE Felhasznalo.C_OKTATASIAZONOSITO IN ({string.Join(",", inCommandParameter)})
                                   AND Felhasznalo.TOROLT = 'F'";

            DataSet dataSet = GetData(
                commandText: commandText,
                parameters: commandParameters);

            return dataSet;
        }

        public DataSet GetBulkAlkalmazottSzamlaAdatok(List<int> kretaFelhasznaloAzonositok, int tanevId)
        {
            var commandParameters = new List<CommandParameter>()
            {
                new CommandParameter(nameof(tanevId), tanevId)
            };

            var inCommandParameter = new List<string>();

            foreach (var azonosito in kretaFelhasznaloAzonositok)
            {
                var name = string.Format("pkretaFelhasznaloAzonosito{0}", kretaFelhasznaloAzonositok.IndexOf(azonosito));

                commandParameters.Add(new CommandParameter(name, azonosito));
                inCommandParameter.Add("@" + name);
            }

            var commandText = $@"SELECT DISTINCT
                                  fh.C_OKTATASIAZONOSITO as OktatasiAzonosito
                                  ,a.ID as KretaAlkalmazottAzonosito
                                  ,fh.C_NYOMTATASINEV AS Nev
                                  ,c.C_ISOKOD AS OrszagISO
                                  ,ISNULL(c.C_ORSZAG, '') AS OrszagKretaAzonosito
                                  ,ISNULL(c.C_NAME, '') AS OrszagNev
                                  ,c.C_IRANYITOSZAM AS Iranyitoszam
                                  ,c.C_VAROS AS Varos
                                  ,c.C_KOZTERULET AS KozteruletNeve
                                  ,c.C_KOZTERULETJELLEGENEV AS KozteruletJellegeNev
                                  ,c.C_HAZSZAM AS Hazszam
                                  ,c.C_EMELET AS Emelet
                                  ,c.C_AJTO AS Ajto
                                  ,fh.C_ADOAZONOSITOJEL AS Adoszam
                                  ,mh.C_FUNKCIOTERULET AS FunkcioTeruletSAPKod
                                FROM T_FELHASZNALO_OSSZES fh
                                  CROSS APPLY fnGetFelhaszaloCim(fh.ID) c
                                  LEFT JOIN T_ALKALMAZOTT_OSSZES a on a.ID = fh.ID
                                    AND a.TOROLT = 'F'
                                  LEFT JOIN T_MUNKAUGYIADATOK_OSSZES ma ON ma.C_ALKALMAZOTTID = fh.ID
                                    AND ma.TOROLT = 'F'
                                    AND ma.C_TANEVID = fh.C_TANEVID
                                  LEFT JOIN T_FELADATELLATASIHELY_OSSZES feh ON feh.ID = ma.C_FELADATELLATASIHELYID
                                    AND feh.TOROLT = 'F'
                                    AND feh.C_TANEVID = fh.C_TANEVID
                                  LEFT JOIN T_MUKODESIHELY_OSSZES mh ON mh.ID = feh.C_MUKODESIHELYID
                                    AND mh.TOROLT = 'F'
                                    AND mh.C_TANEVID = fh.C_TANEVID
                                WHERE fh.ID IN ({string.Join(",", inCommandParameter)})
                                  AND fh.TOROLT = 'F'
                                  AND fh.C_TANEVID = @{nameof(tanevId)}";

            DataSet dataSet = GetData(
                commandText: commandText,
                parameters: commandParameters);

            return dataSet;
        }

        public DataSet GetBulkGondviseloGyerekAdatok(List<int> gondviseloAzonositok)
        {
            var commandParameters = new List<CommandParameter>();
            var inCommandParameter = new List<string>();

            foreach (var azonosito in gondviseloAzonositok)
            {
                var name = string.Format("pGondviseloAzonosito{0}", gondviseloAzonositok.IndexOf(azonosito));

                commandParameters.Add(new CommandParameter(name, azonosito));
                inCommandParameter.Add("@" + name);
            }

            var commandText = $@"SELECT
                                    Felhasznalo.ID AS KretaAzonosito
                                   ,Felhasznalo.C_VEZETEKNEV AS VezetekNev
                                   ,Felhasznalo.C_UTONEV AS KeresztNev
                                   ,Felhasznalo.C_OKTATASIAZONOSITO AS OktatasiAzonosito
                                   ,ISNULL(Felhasznalo.C_ELOTAG, '') AS Elotag
                                 FROM T_FELHASZNALO Felhasznalo
                                 INNER JOIN T_TANULO Tanulo ON Tanulo.ID = Felhasznalo.ID
                                   AND Tanulo.TOROLT = 'F'
                                 WHERE Felhasznalo.TOROLT = 'F'
                                   AND EXISTS (SELECT 1
                                              FROM T_GONDVISELO Gondviselo
                                              WHERE Gondviselo.TOROLT = 'F'
                                                AND Gondviselo.ID IN ({string.Join(",", inCommandParameter)})
                                                AND Gondviselo.C_TANULOID = Felhasznalo.ID)";

            DataSet dataSet = GetData(
                commandText: commandText,
                parameters: commandParameters);

            return dataSet;
        }

        public DataSet GetBulkTanulok(List<string> oktatasiAzonositok, int tanevId)
        {
            var commandParameters = new List<CommandParameter>
            {
                new CommandParameter(nameof(tanevId), tanevId)
            };

            var inCommandParameter = new List<string>();

            foreach (var azonosito in oktatasiAzonositok)
            {
                var name = string.Format("pOktatasiAzonosito{0}", oktatasiAzonositok.IndexOf(azonosito));

                commandParameters.Add(new CommandParameter(name, azonosito));
                inCommandParameter.Add("@" + name);
            }

            var commandText = $@"SELECT
                                    Felhasznalo.ID AS KretaAzonosito
                                   ,Felhasznalo.C_VEZETEKNEV AS VezetekNev
                                   ,Felhasznalo.C_UTONEV AS KeresztNev
                                   ,Felhasznalo.C_OKTATASIAZONOSITO AS OktatasiAzonosito
                                   ,ISNULL(Felhasznalo.C_ELOTAG, '') AS Elotag
                                   ,Felhasznalo.C_EGYEDIAZONOSITO AS EgyediAzonosito
                                   ,Felhasznalo.C_IDPEGYEDIAZONOSITO AS IdpEgyediAzonosito
                                   ,Felhasznalo.C_SZULETESIDATUM AS SzuletesiIdo
                                 FROM T_FELHASZNALO Felhasznalo
                                 INNER JOIN T_TANULO Tanulo ON Tanulo.ID = Felhasznalo.ID
                                   AND Tanulo.TOROLT = 'F'
                                 WHERE Felhasznalo.TOROLT = 'F'
                                   AND Felhasznalo.C_OKTATASIAZONOSITO IN ({string.Join(",", inCommandParameter)})
                                   AND Felhasznalo.C_TANEVID = @{nameof(tanevId)}";

            DataSet dataSet = GetData(
                commandText: commandText,
                parameters: commandParameters);

            return dataSet;
        }

        public DataSet GetElsoAlairo(int tanevId)
        {
            using (var command = new SDACommand())
            {
                command.Connection = UserContext.Instance.SDAConnection;
                command.Transaction = UserContext.Instance.SDATransaction;
                command.CommandType = CommandType.StoredProcedure;
                command.CommandText = "uspGetElsoAlairoEugyintezes";

                command.Parameters.Add("pVezetoiOraszamokTipusEnumNincs", SDADBType.Int).Value = (int)VezetoiOraszamokTipusEnum.Nincs;
                command.Parameters.Add("pVezetoiOraszamokTipusEnumGyakorlatiOktatasvezeto", SDADBType.Int).Value = (int)VezetoiOraszamokTipusEnum.GyakorlatiOktatasvezeto;
                command.Parameters.Add("pTanevId", SDADBType.Int).Value = tanevId;

                var dataSet = new DataSet();
                using (var sdaDataAdapter = new SDADataAdapter())
                {
                    sdaDataAdapter.SelectCommand = command;
                    sdaDataAdapter.Fill(dataSet);
                }
                SetDNAME(dataSet.Tables[0], "Titulus");
                return dataSet;
            }
        }

        public DataSet GetEUgyintezok(int szerepkorTipus, int tanevId)
        {
            using (var command = new SDACommand())
            {
                command.Connection = UserContext.Instance.SDAConnection;
                command.Transaction = UserContext.Instance.SDATransaction;
                command.CommandType = CommandType.StoredProcedure;
                command.CommandText = "uspGetEUgyintezokBySzerepkorTipus";

                command.Parameters.Add("pSzerepkorTipus", szerepkorTipus);
                command.Parameters.Add("pTanevId", tanevId);

                var dataSet = new DataSet();
                using (var sdaDataAdapter = new SDADataAdapter())
                {
                    sdaDataAdapter.SelectCommand = command;
                    sdaDataAdapter.Fill(dataSet);
                }
                SetDNAME(dataSet.Tables[0], "Titulus");
                return dataSet;
            }
        }

        public DataSet GetTanev(int tanevKretaAzonosito)
        {
            using (var command = new SDACommand())
            {
                command.Connection = UserContext.Instance.SDAConnection;
                command.Transaction = UserContext.Instance.SDATransaction;
                command.CommandType = CommandType.StoredProcedure;
                command.CommandText = "uspGetTanevEugyintezes";

                command.Parameters.Add("pTanevKretaAzonosito", tanevKretaAzonosito);

                var dataSet = new DataSet();
                using (var sdaDataAdapter = new SDADataAdapter())
                {
                    sdaDataAdapter.SelectCommand = command;
                    sdaDataAdapter.Fill(dataSet);
                }

                return dataSet;
            }
        }

        public DataSet GetGondviseloGyerekAdatokNextYear(int gondviseloAzonosito, int tanevKretaAzonosito)
        {
            using (var command = new SDACommand())
            {
                command.Connection = UserContext.Instance.SDAConnection;
                command.Transaction = UserContext.Instance.SDATransaction;
                command.CommandType = CommandType.StoredProcedure;
                command.CommandText = "uspGetGondviseloGyerekAdatokNextYearEugyintezes";

                command.Parameters.Add("pTanevId", tanevKretaAzonosito);
                command.Parameters.Add("pGondviseloId", gondviseloAzonosito);

                var dataSet = new DataSet();
                using (var sdaDataAdapter = new SDADataAdapter())
                {
                    sdaDataAdapter.SelectCommand = command;
                    sdaDataAdapter.Fill(dataSet);
                }

                return dataSet;
            }
        }

        public DataSet GetTanitasiRendKivetelNapok(DateTime kezdete, DateTime vege, int intezmenyId)
        {
            using (var command = new SDACommand())
            {
                command.Connection = UserContext.Instance.SDAConnection;
                command.Transaction = UserContext.Instance.SDATransaction;
                command.CommandType = CommandType.StoredProcedure;
                command.CommandText = "uspGetTanitasiRendKivetelNapokEugyintezes";

                command.Parameters.Add("pIntezmenyId", intezmenyId);
                command.Parameters.Add("pKezdete", kezdete);
                command.Parameters.Add("pVege", vege);

                var dataSet = new DataSet();
                using (var sdaDataAdapter = new SDADataAdapter())
                {
                    sdaDataAdapter.SelectCommand = command;
                    sdaDataAdapter.Fill(dataSet);
                }

                return dataSet;
            }
        }

        public int GetIntezmenyId(string intezmenyAzonosito)
        {
            using (var command = new SDACommand())
            {
                command.Connection = UserContext.Instance.SDAConnection;
                command.Transaction = UserContext.Instance.SDATransaction;
                command.CommandType = CommandType.StoredProcedure;
                command.CommandText = "uspGetIntezmenyIdByAzonositoEugyintezes";

                command.Parameters.Add("pIntezmenyAzonosito", intezmenyAzonosito);

                var dataSet = new DataSet();
                using (var sdaDataAdapter = new SDADataAdapter())
                {
                    sdaDataAdapter.SelectCommand = command;
                    sdaDataAdapter.Fill(dataSet);
                }

                int id = 0;
                if (dataSet.Tables[0].Rows.Count > 0)
                {
                    id = dataSet.Tables[0].Rows[0].Field<int>("ID");
                }

                return id;
            }
        }

        public int GetTanevId(int kretaFelhasznaloAzonosito)
        {
            using (var command = new SDACommand())
            {
                command.Connection = UserContext.Instance.SDAConnection;
                command.Transaction = UserContext.Instance.SDATransaction;
                command.CommandType = CommandType.StoredProcedure;
                command.CommandText = "uspGetTanevIdByFelhasznaloAzonositoEugyintezes";

                command.Parameters.Add("pFelhasznaloId", kretaFelhasznaloAzonosito);

                var dataSet = new DataSet();
                using (var sdaDataAdapter = new SDADataAdapter())
                {
                    sdaDataAdapter.SelectCommand = command;
                    sdaDataAdapter.Fill(dataSet);
                }

                int id = 0;
                if (dataSet.Tables[0].Rows.Count > 0)
                {
                    id = dataSet.Tables[0].Rows[0].Field<int>("C_TANEVID");
                }

                return id;
            }
        }

        public int GetTanevId(string tanuloOktatasiAzonosito, int intezmenyId)
        {
            using (var command = new SDACommand())
            {
                command.Connection = UserContext.Instance.SDAConnection;
                command.Transaction = UserContext.Instance.SDATransaction;
                command.CommandType = CommandType.StoredProcedure;
                command.CommandText = "uspGetTanevIdByOktatasiAzonositoEugyintezes";

                command.Parameters.Add("pTanuloOktatasiAzonosito", tanuloOktatasiAzonosito);
                command.Parameters.Add("pIntezmenyId", intezmenyId);

                var dataSet = new DataSet();
                using (var sdaDataAdapter = new SDADataAdapter())
                {
                    sdaDataAdapter.SelectCommand = command;
                    sdaDataAdapter.Fill(dataSet);
                }

                int id = 0;
                if (dataSet.Tables[0].Rows.Count > 0)
                {
                    id = dataSet.Tables[0].Rows[0].Field<int>("ID");
                }

                return id;
            }
        }

        public int GetGondviseloTanevId(int kretaFelhasznaloAzonosito)
        {
            using (var command = new SDACommand())
            {
                command.Connection = UserContext.Instance.SDAConnection;
                command.Transaction = UserContext.Instance.SDATransaction;
                command.CommandType = CommandType.StoredProcedure;
                command.CommandText = "uspGetGondviseloTanevIdEugyintezes";

                command.Parameters.Add("pFelhasznaloId", kretaFelhasznaloAzonosito);

                var dataSet = new DataSet();
                using (var sdaDataAdapter = new SDADataAdapter())
                {
                    sdaDataAdapter.SelectCommand = command;
                    sdaDataAdapter.Fill(dataSet);
                }

                int id = 0;
                if (dataSet.Tables[0].Rows.Count > 0)
                {
                    id = dataSet.Tables[0].Rows[0].Field<int>("C_TANEVID");
                }

                return id;
            }
        }

        public int GetOsztalycsoportTanevId(int azonosito)
        {
            using (var command = new SDACommand())
            {
                command.Connection = UserContext.Instance.SDAConnection;
                command.Transaction = UserContext.Instance.SDATransaction;
                command.CommandType = CommandType.StoredProcedure;
                command.CommandText = "uspGetOsztalycsoportTanevIdEugyintezes";

                command.Parameters.Add("pOsztalycsoportId", azonosito);

                var dataSet = new DataSet();
                using (var sdaDataAdapter = new SDADataAdapter())
                {
                    sdaDataAdapter.SelectCommand = command;
                    sdaDataAdapter.Fill(dataSet);
                }

                int id = 0;
                if (dataSet.Tables[0].Rows.Count > 0)
                {
                    id = dataSet.Tables[0].Rows[0].Field<int>("C_TANEVID");
                }

                return id;
            }
        }

        public int GetTantargyTanevId(int azonosito)
        {
            using (var command = new SDACommand())
            {
                command.Connection = UserContext.Instance.SDAConnection;
                command.Transaction = UserContext.Instance.SDATransaction;
                command.CommandType = CommandType.StoredProcedure;
                command.CommandText = "uspGetTantargyTanevIdEugyintezes";

                command.Parameters.Add("pTantargyId", azonosito);

                var dataSet = new DataSet();
                using (var sdaDataAdapter = new SDADataAdapter())
                {
                    sdaDataAdapter.SelectCommand = command;
                    sdaDataAdapter.Fill(dataSet);
                }

                int id = 0;
                if (dataSet.Tables[0].Rows.Count > 0)
                {
                    id = dataSet.Tables[0].Rows[0].Field<int>("C_TANEVID");
                }

                return id;
            }
        }

        public DataSet GetTanuloByDiakigazolvanyszam(string diakigazolvanyszam)
        {
            using (var command = new SDACommand())
            {
                command.Connection = UserContext.Instance.SDAConnection;
                command.Transaction = UserContext.Instance.SDATransaction;
                command.CommandType = CommandType.StoredProcedure;
                command.CommandText = "uspGetTanuloByDiakigazolvanyszamEugyintezes";

                command.Parameters.Add("pDiakigazolvanyszam", diakigazolvanyszam);

                var dataSet = new DataSet();
                using (var sdaDataAdapter = new SDADataAdapter())
                {
                    sdaDataAdapter.SelectCommand = command;
                    sdaDataAdapter.Fill(dataSet);
                }

                return dataSet;
            }
        }

        public DataSet GetTanuloOsszesOsztalyanakAdataiByTanuloId(int tanuloId, int? tanevKretaAzonosito)
        {
            var tanevWhereClause = tanevKretaAzonosito.HasValue ? $"ID = @{nameof(tanevKretaAzonosito)}" : "C_AKTIV = 'T'";
            var tanuloCsoportWhereClause = tanevKretaAzonosito.HasValue ? $"AND TanuloCsoport.C_TANEVID = @{nameof(tanevKretaAzonosito)}" : "";
            var commandText =
                $@"
                    SELECT
                         OsztalyCsoport.ID AS KretaAzonosito
                        ,OsztalyCsoport.C_NEV AS Nev
                        ,OsztalyCsoport.C_FELADATKATEGORIAID AS OktNevelesiKategoriaKretaAzonosito
                    FROM T_TANULOCSOPORT_OSSZES TanuloCsoport
                    INNER JOIN T_OSZTALY_OSSZES Osztaly ON Osztaly.ID = TanuloCsoport.C_OSZTALYCSOPORTID
                        AND Osztaly.C_ALTANEVID = TanuloCsoport.C_TANEVID
                        AND Osztaly.TOROLT = 'F'
                    INNER JOIN T_OSZTALYCSOPORT_OSSZES OsztalyCsoport ON OsztalyCsoport.ID = Osztaly.ID
                        AND OsztalyCsoport.C_TANEVID = TanuloCsoport.C_TANEVID
                        AND OsztalyCsoport.TOROLT = 'F'
                    WHERE TanuloCsoport.C_TANULOID = @{nameof(tanuloId)}
                        AND TanuloCsoport.TOROLT = 'F'
                        AND TanuloCsoport.C_BELEPESDATUM <= (SELECT IIF(GETDATE() < C_ELSOTANITASINAP, C_ELSOTANITASINAP, GETDATE()) FROM T_TANEV WHERE {tanevWhereClause} AND TOROLT = 'F')
                        AND (TanuloCsoport.C_KILEPESDATUM IS NULL OR TanuloCsoport.C_KILEPESDATUM > GETDATE())
                        {tanuloCsoportWhereClause}
                ";

            var commandParameterList = new List<CommandParameter>
            {
                new CommandParameter(nameof(tanuloId), tanuloId)
            };

            if (tanevKretaAzonosito.HasValue)
            {
                commandParameterList.Add(new CommandParameter(nameof(tanevKretaAzonosito), tanevKretaAzonosito));
            }

            var ds = GetData(commandText: commandText, parameters: commandParameterList);

            return ds;
        }

        public DataSet GetVezetettTanoraiCsoportok(int alkalmazottKretaAzonosito)
        {
            using (var command = new SDACommand())
            {
                command.Connection = UserContext.Instance.SDAConnection;
                command.Transaction = UserContext.Instance.SDATransaction;
                command.CommandType = CommandType.StoredProcedure;
                command.CommandText = "uspGetVezetettTanoraiCsoportokEugyintezes";

                command.Parameters.Add("pAlkalmazottId", alkalmazottKretaAzonosito);

                var dataSet = new DataSet();
                using (var sdaDataAdapter = new SDADataAdapter())
                {
                    sdaDataAdapter.SelectCommand = command;
                    sdaDataAdapter.Fill(dataSet);
                }

                return dataSet;
            }
        }

        public DataSet GetTanitottTanoraiCsoportok(int alkalmazottKretaAzonosito)
        {
            using (var command = new SDACommand())
            {
                command.Connection = UserContext.Instance.SDAConnection;
                command.Transaction = UserContext.Instance.SDATransaction;
                command.CommandType = CommandType.StoredProcedure;
                command.CommandText = "uspGetTanitottTanoraiCsoportokEugyintezes";

                command.Parameters.Add("pAlkalmazottId", alkalmazottKretaAzonosito);

                var dataSet = new DataSet();
                using (var sdaDataAdapter = new SDADataAdapter())
                {
                    sdaDataAdapter.SelectCommand = command;
                    sdaDataAdapter.Fill(dataSet);
                }

                return dataSet;
            }
        }

        public DataSet GetBulkTanuloAdatok(List<int> kretaAzonositok)
        {
            var commandParameters = new List<CommandParameter>();
            var inCommandParameter = new List<string>();

            foreach (var azonosito in kretaAzonositok)
            {
                var name = string.Format("pKretaAzonositok{0}", kretaAzonositok.IndexOf(azonosito));

                commandParameters.Add(new CommandParameter(name, azonosito));
                inCommandParameter.Add("@" + name);
            }

            var commandText = $@"
                SELECT
                    t.ID as KretaAzonosito
                    ,f.C_EGYEDIAZONOSITO as EgyediAzonosito
                    ,f.C_IDPEGYEDIAZONOSITO AS IdpEgyediAzonosito
                    ,f.C_VEZETEKNEV as VezetekNev
                    ,f.C_UTONEV as KeresztNev
                FROM T_TANULO_OSSZES t
                JOIN T_FELHASZNALO_OSSZES f on f.ID = t.ID
                WHERE
                    t.ID IN ({string.Join(",", inCommandParameter)})
                    AND t.TOROLT = 'F' AND f.TOROLT = 'F'
            ";

            DataSet dataSet = GetData(commandText: commandText, parameters: commandParameters);
            return dataSet;
        }

        public DataSet GetBulkGondviseloAdatok(List<int> kretaAzonositok)
        {
            var commandParameters = new List<CommandParameter>();
            var inCommandParameter = new List<string>();

            foreach (var azonosito in kretaAzonositok)
            {
                var name = string.Format("pKretaAzonositok{0}", kretaAzonositok.IndexOf(azonosito));

                commandParameters.Add(new CommandParameter(name, azonosito));
                inCommandParameter.Add("@" + name);
            }

            var commandText = $@"
                SELECT
                    g.ID as KretaAzonosito
                    ,g.C_EGYEDIAZONOSITO as EgyediAzonosito
                    ,g.C_IDPEGYEDIAZONOSITO AS IdpEgyediAzonosito
                    ,g.C_NEV as GondviseloNev
                    ,f.C_NYOMTATASINEV as TanuloNev
                    ,f.ID as TanuloKretaAzonosito
                FROM T_GONDVISELO_OSSZES g
                JOIN T_FELHASZNALO_OSSZES f on f.ID = g.C_TANULOID                
                WHERE
                    g.ID IN ({string.Join(",", inCommandParameter)})
                    AND g.TOROLT = 'F' AND f.TOROLT = 'F'
            ";

            DataSet dataSet = GetData(commandText: commandText, parameters: commandParameters);
            return dataSet;
        }

        public DataSet GetBulkAlkalmazottAdatok(List<int> kretaAzonositok)
        {
            var commandParameters = new List<CommandParameter>();
            var inCommandParameter = new List<string>();

            foreach (var azonosito in kretaAzonositok)
            {
                var name = string.Format("pKretaAzonositok{0}", kretaAzonositok.IndexOf(azonosito));

                commandParameters.Add(new CommandParameter(name, azonosito));
                inCommandParameter.Add("@" + name);
            }

            var commandText = $@"
                SELECT
                    Alkalmazott.ID as KretaAzonosito
                    ,Felhasznalo.C_EGYEDIAZONOSITO as EgyediAzonosito
                    ,Felhasznalo.C_IDPEGYEDIAZONOSITO AS IdpEgyediAzonosito
                    ,IIF(MunkaugyiAdatok.C_VEZETOIORASZAMOK IN (7755, 6572, 6573, 7757, 7758, 6574), 1, 0) AS IsIgazgato
                    ,IIF(MunkaugyiAdatok.C_VEZETOIORASZAMOK IN (7756, 6575, 6576, 6577), 1, 0) AS IsIgazgatoHelyettes
                    ,IIF(Osztaly.OsztalyfonokId = Alkalmazott.ID, 1, 0) AS IsOsztalyfonok
                    ,IIF(OsztalyHelyettes.OsztalyfonokHelyettesId = Alkalmazott.ID, 1, 0) AS IsOsztalyfonokHelyettes
                    ,IIF(Adminisztrator.FelhasznaloId = Alkalmazott.ID, 1, 0) AS IsAdmin
                    ,IIF(Szuro.C_MUNKAKORTIPUSA IS NOT NULL, 1, 0) AS IsTanar
                    ,Felhasznalo.C_NYOMTATASINEV as Nev
                FROM T_ALKALMAZOTT_OSSZES Alkalmazott
                JOIN T_FELHASZNALO_OSSZES Felhasznalo on Felhasznalo.ID = Alkalmazott.ID
                LEFT JOIN (
                        SELECT MunkaugyiAdatok.C_ALKALMAZOTTID, MunkaugyiAdatok.C_MUNKAKORTIPUSA
                        FROM T_MUNKAUGYIADATOK_OSSZES MunkaugyiAdatok
                        INNER JOIN T_FELHASZNALO_SZEREPKOR FelhasznaloSzerepkor ON FelhasznaloSzerepkor.C_FELHASZNALOID = MunkaugyiAdatok.C_ALKALMAZOTTID
                        INNER JOIN T_SZEREPKOR_OSSZES Szerepkor ON Szerepkor.ID = FelhasznaloSzerepkor.C_SZEREPKORID AND Szerepkor.TOROLT = 'F' AND Szerepkor.C_SZEREPKORTIPUS = 1760 /*Napló*/
                        WHERE MunkaugyiAdatok.C_MUNKAKORTIPUSA NOT IN (
                                SELECT
                                    JSON_VALUE(VALUE,'$.Value')
                                FROM OPENJSON((
                                    SELECT RendszerBeallitas.C_ERTEK
                                    FROM T_RENDSZERBEALLITAS RendszerBeallitas
                                    WHERE RendszerBeallitas.C_BEALLITASTIPUS = 5441 /*Alkalmazottak láthatják-e a diákok adatait*/ AND RendszerBeallitas.TOROLT = 'F'
                                ),'$.Options')
                                WHERE JSON_VALUE(VALUE,'$.Selected') = 'true') OR MunkaugyiAdatok.C_MUNKAKORTIPUSA = 6710 /*Hitoktató*/
                        AND MunkaugyiAdatok.TOROLT = 'F' ) Szuro ON Szuro.C_ALKALMAZOTTID = Felhasznalo.ID
                LEFT JOIN (SELECT Osztaly.C_OSZTALYFONOKID AS OsztalyfonokId
                            FROM T_OSZTALYCSOPORT_OSSZES OsztalyCsoport
                            INNER JOIN T_OSZTALY_OSSZES Osztaly ON Osztaly.ID = OsztalyCsoport.ID AND Osztaly.TOROLT = 'F'
                            WHERE OsztalyCsoport.TOROLT = 'F' AND Osztaly.C_OSZTALYFONOKID in ({string.Join(",", inCommandParameter)})
                    ) Osztaly ON Osztaly.OsztalyfonokId = Alkalmazott.ID
                LEFT JOIN (SELECT Osztaly.C_OFOHELYETTESID AS OsztalyfonokHelyettesId
                            FROM T_OSZTALYCSOPORT_OSSZES OsztalyCsoport
                            INNER JOIN T_OSZTALY_OSSZES Osztaly ON Osztaly.ID = OsztalyCsoport.ID AND Osztaly.TOROLT = 'F'
                            WHERE OsztalyCsoport.TOROLT = 'F' AND Osztaly.C_OFOHELYETTESID in ({string.Join(",", inCommandParameter)})
                    ) OsztalyHelyettes ON OsztalyHelyettes.OsztalyfonokHelyettesId = Alkalmazott.ID
                LEFT JOIN (SELECT FelhasznaloSzerepkor.C_FELHASZNALOID AS FelhasznaloId
                            FROM T_FELHASZNALO_SZEREPKOR FelhasznaloSzerepkor
                            INNER JOIN T_SZEREPKOR_OSSZES Szerepkor ON Szerepkor.ID = FelhasznaloSzerepkor.C_SZEREPKORID AND Szerepkor.TOROLT = 'F' AND Szerepkor.C_SZEREPKORTIPUS = 1758 /*Adminisztrátor*/
                            WHERE FelhasznaloSzerepkor.C_FELHASZNALOID IN ({string.Join(",", inCommandParameter)})
                    ) Adminisztrator ON Adminisztrator.FelhasznaloId = Alkalmazott.ID
                LEFT JOIN T_MUNKAUGYIADATOK_OSSZES MunkaugyiAdatok ON MunkaugyiAdatok.C_ALKALMAZOTTID = Alkalmazott.ID AND MunkaugyiAdatok.TOROLT = 'F'
                WHERE
                    Alkalmazott.ID IN ({string.Join(",", inCommandParameter)})
                    AND Alkalmazott.TOROLT = 'F' AND Felhasznalo.TOROLT = 'F'
            ";

            DataSet dataSet = GetData(commandText: commandText, parameters: commandParameters);
            return dataSet;
        }

        public DataSet GetOrszagTipus(int orszagKretaAzonosito, int tanevId)
        {
            using (var command = new SDACommand())
            {
                command.Connection = UserContext.Instance.SDAConnection;
                command.Transaction = UserContext.Instance.SDATransaction;
                command.CommandType = CommandType.StoredProcedure;
                command.CommandText = "uspGetOrszagTipusEugyintezes";

                command.Parameters.Add("pTanevId", tanevId);
                command.Parameters.Add("pOrszagId", orszagKretaAzonosito);
                command.Parameters.Add("pTipusId", (int)GeneratedAdatszotarTipusEnum.OrszagTipus);

                var dataSet = new DataSet();
                using (var sdaDataAdapter = new SDADataAdapter())
                {
                    sdaDataAdapter.SelectCommand = command;
                    sdaDataAdapter.Fill(dataSet);
                }

                return dataSet;
            }
        }

        public DataSet GetOrszagTipusok(int tanevId)
        {
            using (var command = new SDACommand())
            {
                command.Connection = UserContext.Instance.SDAConnection;
                command.Transaction = UserContext.Instance.SDATransaction;
                command.CommandType = CommandType.StoredProcedure;
                command.CommandText = "uspGetOrszagTipusokEugyintezes";

                command.Parameters.Add("pTanevId", tanevId);
                command.Parameters.Add("pTipusId", (int)GeneratedAdatszotarTipusEnum.OrszagTipus);

                var dataSet = new DataSet();
                using (var sdaDataAdapter = new SDADataAdapter())
                {
                    sdaDataAdapter.SelectCommand = command;
                    sdaDataAdapter.Fill(dataSet);
                }

                return dataSet;
            }
        }

        public DataSet GetTanuloAdatok(Guid tanuloIdpEgyediAznosito, int tanevId)
        {
            using (var command = new SDACommand())
            {
                command.Connection = UserContext.Instance.SDAConnection;
                command.Transaction = UserContext.Instance.SDATransaction;
                command.CommandType = CommandType.StoredProcedure;
                command.CommandText = "uspGetTanuloAdatokEugyintezesByIdpEgyediAzonosito";

                command.Parameters.Add("pIdpAzonosito", tanuloIdpEgyediAznosito);
                command.Parameters.Add("pTanevId", tanevId);

                var dataSet = new DataSet();
                using (var sdaDataAdapter = new SDADataAdapter())
                {
                    sdaDataAdapter.SelectCommand = command;
                    sdaDataAdapter.Fill(dataSet);
                }

                return dataSet;
            }
        }

        public DataSet GetTanuloAdatokNextYear(Guid tanuloIdpEgyediAznosito, int tanevKretaAzonosito)
        {
            using (var command = new SDACommand())
            {
                command.Connection = UserContext.Instance.SDAConnection;
                command.Transaction = UserContext.Instance.SDATransaction;
                command.CommandType = CommandType.StoredProcedure;
                command.CommandText = "uspGetTanuloAdatokNextYearEugyintezesByIdpEgyediAzonosito";

                command.Parameters.Add("pIdpAzonosito", tanuloIdpEgyediAznosito);
                command.Parameters.Add("pTanevId", tanevKretaAzonosito);

                var dataSet = new DataSet();
                using (var sdaDataAdapter = new SDADataAdapter())
                {
                    sdaDataAdapter.SelectCommand = command;
                    sdaDataAdapter.Fill(dataSet);
                }

                return dataSet;
            }
        }
    }
}
